****************************************************************
*** Do file to replicate the macro-analysis for "Estimating the Defense Spending Vote"
***
****************************************************************

*** Set up the working directory
*cd ""

use "DSV.dta", clear

****************************************************************************************************
*** Figure 1: Defense spending vote for each party in the sample
****************************************************************************************************
sum pr, det

twoway scatter pr id 
tab id if pr > 0
tab id if pr < 0

tab sig
tab sig if pr < 0
tab sig if pr > 0
pwcorr rile milspend, sig

*** All parties
sort id
twoway (rcap lo hi id) (line pr id), yline(0, lpattern(dash)) legend(off) xtitle("Party Identifier") ytitle("Defense Spending Vote") 

****************************************************************************************************
*** Figure 2: Partisanship and the defense spending vote
****************************************************************************************************
*** Left-Right Ideology
sort rile
reg pr rile [pw=1/se], robust cluster(party)
twoway (rcap lo hi rile) (lfit pr rile), legend(off) ytitle("Defense Spending Vote") xtitle("Left									Right""Ideology") name(i, replace)

*** Defense Spending Emphasis
sort milspend
reg pr milspend [pw=1/se], robust cluster(party)
twoway (rcap lo hi milspend) (lfit pr milspend), legend(off) ytitle("Defense Spending Vote") xtitle("Negative									Positive""Defense Spending Emphasis") name(d, replace)

graph combine i d

****************************************************************************************************
*** Figure 3: Partisanship, international hostilities and the defense spending vote
****************************************************************************************************
*** Left-right, conditional on MIDs
gen mid_count_h_36_rile = mid_count_h_36 * rile
reg pr rile mid_count_h_36 mid_count_h_36_rile [pw=1/se], robust cluster(party)
local nomid = round(_b[rile], .0001)
local mid = round((_b[rile] + 1 * _b[mid_count_h_36_rile]), .0001)
test rile = (rile + 1*mid_count_h_36_rile)

reg pr rile if mid_count_h_36 == 0 [pw=1/se], robust cluster(party)
reg pr rile if mid_count_h_36 > 0 [pw=1/se], robust cluster(party)

twoway (rcap lo hi rile) (lfit pr rile) if mid_count_h_36 == 0, legend(off) ytitle("Defense Spending Vote") xtitle("Left												Right""Ideology") name(p0, replace)	

twoway (rcap lo hi rile) (lfit pr rile) if mid_count_h_36 > 0, legend(off) ytitle("Defense Spending Vote") xtitle("Left												Right""Ideology") name(p1, replace)
	
*** Military spending position, conditional on MIDs
gen mid_count_h_36_milspend = mid_count_h_36 * milspend
reg pr milspend mid_count_h_36 mid_count_h_36_milspend [pw=1/se], robust cluster(party)
local nomid = round(_b[milspend], .0001)
local mid = round((_b[milspend] + 1 * _b[mid_count_h_36_milspend]), .0001)
test milspend = (milspend + 1*mid_count_h_36_milspend)

reg pr milspend if mid_count_h_36 == 0 [pw=1/se], robust cluster(party)
reg pr milspend if mid_count_h_36 > 0 [pw=1/se], robust cluster(party)

twoway (rcap lo hi milspend) (lfit pr milspend) if mid_count_h_36 == 0, legend(off) ytitle("Defense Spending Vote") xtitle("Negative										Positive""Defense Spending Emphasis") name(d0, replace)	

twoway (rcap lo hi milspend) (lfit pr milspend) if mid_count_h_36 > 0, legend(off) ytitle("Defense Spending Vote") xtitle("Negative										Positive""Defense Spending Emphasis") name(d1, replace)

graph combine p0 d0 p1 d1

****************************************************************************************************
*** Figure 4: Box-whisker plots of the defense spending vote across partisanship and PM/largest opposition party
****************************************************************************************************
graph box pr, yline(0, lpattern(dash)) over(lr_pm) ytitle("Defense Spending Vote")
graph box pr, yline(0, lpattern(dash)) over(lr_pm2) ytitle("Defense Spending Vote")


****************************************************************************************************
****************************************************************************************************
**************************** Robustness Checks *****************************************************
****************************************************************************************************
****************************************************************************************************

****************************************************************************************************
*** Change in probability of voting as income quartile goes from 1 to 4
****************************************************************************************************
clear all
use "ISSP--Income--Vote Choice.dta", clear
cap drop __*

sum pr, det

tab id if pr > 0
tab id if pr < 0

tab sig
tab sig if pr < 0
tab sig if pr > 0
twoway scatter pr id 

*** All parties
sort id
twoway (rcap lo hi id) (line pr id), yline(0, lpattern(dash)) legend(off) xtitle("Party") ytitle("Change in Probability of Voting for Party") note("Bars represent 90% confidence intervals") 

****************************************************************************************************
*** Assessing the model fit of the international hostilities variables
****************************************************************************************************
use "ISSP--Defense Spending--Vote Choice.dta", clear

foreach v of varlist mid_count_h_6 mid_count_h_12 mid_count_h_18 mid_count_h_24 mid_count_h_36 mid_count_h {
	di "Variable is `v'"
	gen `v'_rile = `v' * rile
	reg pr `v' rile `v'_rile [pw=1/se], robust cluster(party)
}

