****************************************************************
*** Do file to create the ISSP--Defense Spending--Vote Choice data set.
***
****************************************************************

* Set up the working directory
*cd ""

global rhs "spend_health_3 spend_defense_3 create_jobs_favor cut_gov_spending_3 male age income_quartile public_employee_d union educ religiosity" /* I removed unemployment */
global y85 "lower_class hh_tax_high world_worse redistribute_agree progressive_tax_agree"
global y90 "lower_class own_home redistribute_agree progressive_tax_agree"
global y96 "lower_class redistribute_agree"
global y06 "retro_threats"

global v "spend_defense_3 1 3"

****************************************************************
*** Code that creates the country-specific data sets containing the effects of defense spending support on probabilities of voting for each party (MNL).
****************************************************************
use "ISSP--Defense Spending.dta", clear

*** Ireland 1996
preserve
	local cc = 205
	local y = 1996
	keep if ccode == `cc' & year == `y'

	recode vote1 (3 5/6=.) (4=3)

	qui mlogit vote1 $rhs $y96, base(2) nolog

	postfile pr ccode year obs pr1 pr2 pr3 se1 se2 se3 using "Ireland--1996.dta", replace

	keep if e(sample)
	local obs = `e(N)'
	estsimp `e(cmdline)'
	qui foreach n of numlist 1(1)`obs' {
		setx [`n']
		simqi, fd(genpr(pr1 pr2 pr3)) changex($v)
		foreach p of numlist 1(1)3 {
			qui sum pr`p'
			local pr`p' = r(mean)
			local se`p' = r(sd)
		}
		post pr (`cc') (`y') (`n') (`pr1') (`pr2') (`pr3') (`se1') (`se2') (`se3')
		cap drop pr*	
		if mod(`n',50) == 0 {
			nois display "." _c
			if mod(`n',1000) == 0 {
				nois display ""
			}
		}			
	}
	postclose pr
restore

preserve
	use "Ireland--1996.dta", clear
	foreach v in party pr se govt pm {
		gen `v' = .
	}
	foreach n of numlist 1(1)3 {
		qui sum pr`n'
		local mn`n' = r(mean)
		qui sum se`n'
		local se`n' = r(mean)
		di as result "Change in probability for party `n' " = `mn`n'' "  95% CI = [" `mn`n''-(1.96*`se`n'') ", " `mn`n''+(1.96*`se`n'')
		
		replace pr = `mn`n'' in `n'
		replace se = `se`n'' in `n'
	}	
	replace party = 53520 in 1
	replace party = 53320 in 2
	replace party = 53620 in 3
	replace pm = 1 in 1
	replace g = 1 in 1/2	
	
	drop pr1-se3
	gen N = _N
	drop if _n > 3
	sort ccode year
	save "Ireland--1996.dta", replace
restore

*** Britain 2006
preserve
	local cc = 200
	local y = 2006
	keep if ccode == `cc' & year == `y'

	qui mlogit vote1 $rhs $y06, base(2) nolog
	
	postfile pr ccode year obs pr1 pr2 pr3 se1 se2 se3 using "GB--2006.dta", replace

	keep if e(sample)
	local obs = `e(N)'
	estsimp `e(cmdline)'
	qui foreach n of numlist 1(1)`obs' {
		setx [`n']
		simqi, fd(genpr(pr1 pr2 pr3)) changex($v)
		foreach p of numlist 1(1)3 {
			qui sum pr`p'
			local pr`p' = r(mean)
			local se`p' = r(sd)
		}
		post pr (`cc') (`y') (`n') (`pr1') (`pr2') (`pr3') (`se1') (`se2') (`se3')
		cap drop pr*	
		if mod(`n',50) == 0 {
			nois display "." _c
			if mod(`n',1000) == 0 {
				nois display ""
			}
		}			
	}
	postclose pr
restore

preserve
	use "GB--2006.dta", clear
	foreach v in party pr se govt pm {
		gen `v' = .
	}
	foreach n of numlist 1(1)3 {
		qui sum pr`n'
		local mn`n' = r(mean)
		qui sum se`n'
		local se`n' = r(mean)
		di as result "Change in probability for party `n' " = `mn`n'' "  95% CI = [" `mn`n''-(1.96*`se`n'') ", " `mn`n''+(1.96*`se`n'')
		
		replace pr = `mn`n'' in `n'
		replace se = `se`n'' in `n'
	}	
	replace party = 51320 in 1
	replace party = 51620 in 2
	replace party = 51421 in 3
	replace pm = 1 in 1
	replace g = 1 in 1	
	
	drop pr1-se3
	gen N = _N
	drop if _n > 3
	sort ccode year
	save "GB--2006.dta", replace
restore

*** Britain 1996
preserve
	local cc = 200
	local y = 1996
	keep if ccode == `cc' & year == `y'

	recode vote1 (6=.)

	qui mlogit vote1 $rhs $y96, base(2) nolog
	
	postfile pr ccode year obs pr1 pr2 pr3 se1 se2 se3 using "GB--1996.dta", replace

	keep if e(sample)
	local obs = `e(N)'
	estsimp `e(cmdline)'
	qui foreach n of numlist 1(1)`obs' {
		setx [`n']
		simqi, fd(genpr(pr1 pr2 pr3)) changex($v)
		foreach p of numlist 1(1)3 {
			qui sum pr`p'
			local pr`p' = r(mean)
			local se`p' = r(sd)
		}
		post pr (`cc') (`y') (`n') (`pr1') (`pr2') (`pr3') (`se1') (`se2') (`se3')
		cap drop pr*	
		if mod(`n',50) == 0 {
			nois display "." _c
			if mod(`n',1000) == 0 {
				nois display ""
			}
		}			
	}
	postclose pr
restore

preserve
	use "GB--1996.dta", clear
	foreach v in party pr se govt pm {
		gen `v' = .
	}	
	foreach n of numlist 1(1)3 {
		qui sum pr`n'
		local mn`n' = r(mean)
		qui sum se`n'
		local se`n' = r(mean)
		di as result "Change in probability for party `n' " = `mn`n'' "  95% CI = [" `mn`n''-(1.96*`se`n'') ", " `mn`n''+(1.96*`se`n'')
		
		replace pr = `mn`n'' in `n'
		replace se = `se`n'' in `n'
	}	
	replace party = 51620 in 1
	replace party = 51320 in 2
	replace party = 51421 in 3
	replace pm = 1 in 1
	replace g = 1 in 1	
	
	drop pr1-se3
	gen N = _N	
	drop if _n > 3
	sort ccode year
	save "GB--1996.dta", replace
restore

*** Britain 1990
preserve
	local cc = 200
	local y = 1990
	keep if ccode == `cc' & year == `y'

	qui	mlogit vote1 $rhs own_home redistribute_agree progressive_tax_agree, base(2) nolog
	postfile pr ccode year obs pr1 pr2 pr3 pr4 se1 se2 se3 se4 using "GB--1990.dta", replace

	keep if e(sample)
	local obs = `e(N)'
	estsimp `e(cmdline)'
	qui foreach n of numlist 1(1)`obs' {
		setx [`n']
		simqi, fd(genpr(pr1 pr2 pr3 pr4)) changex($v)
		foreach p of numlist 1(1)4 {
			qui sum pr`p'
			local pr`p' = r(mean)
			local se`p' = r(sd)
		}
		post pr (`cc') (`y') (`n') (`pr1') (`pr2') (`pr3') (`pr4') (`se1') (`se2') (`se3') (`se4')
		cap drop pr1 - pr4	
		if mod(`n',50) == 0 {
			nois display "." _c
			if mod(`n',1000) == 0 {
				nois display ""
			}
		}			
	}
	postclose pr
restore

preserve
	use "GB--1990.dta", clear
	foreach v in party pr se govt pm {
		gen `v' = .
	}	
	foreach n of numlist 1(1)4 {
		qui sum pr`n'
		local mn`n' = r(mean)
		qui sum se`n'
		local se`n' = r(mean)
		di as result "Change in probability for party `n' " = `mn`n'' "  95% CI = [" `mn`n''-(1.96*`se`n'') ", " `mn`n''+(1.96*`se`n'')
		
		replace pr = `mn`n'' in `n'
		replace se = `se`n'' in `n'
	}	
	replace party = 51620 in 1
	replace party = 51320 in 2
	replace party = 51420 in 3
	replace party = 51330 in 4
	replace pm = 1 in 1
	replace g = 1 in 1	
	
	drop pr1-se4
	gen N = _N	
	drop if _n > 4
	sort ccode year
	save "GB--1990.dta", replace
restore

*** Britain 1985
preserve
	local cc = 200
	local y = 1985
	keep if ccode == `cc' & year == `y'

	qui mlogit vote1 $rhs $y85, base(2) nolog
	
	postfile pr ccode year obs pr1 pr2 pr3 pr4 se1 se2 se3 se4 using "GB--1985.dta", replace

	keep if e(sample)
	local obs = `e(N)'
	estsimp `e(cmdline)'
	qui foreach n of numlist 1(1)`obs' {
		setx [`n']
		simqi, fd(genpr(pr1 pr2 pr3 pr4)) changex($v)
		foreach p of numlist 1(1)4 {
			qui sum pr`p'
			local pr`p' = r(mean)
			local se`p' = r(sd)
		}
		post pr (`cc') (`y') (`n') (`pr1') (`pr2') (`pr3') (`pr4') (`se1') (`se2') (`se3') (`se4')
		cap drop pr1 - pr4	
		if mod(`n',50) == 0 {
			nois display "." _c
			if mod(`n',1000) == 0 {
				nois display ""
			}
		}			
	}
	postclose pr
restore

preserve
	use "GB--1985.dta", clear
	foreach v in party pr se govt pm {
		gen `v' = .
	}	
	foreach n of numlist 1(1)4 {
		qui sum pr`n'
		local mn`n' = r(mean)
		qui sum se`n'
		local se`n' = r(mean)
		di as result "Change in probability for party `n' " = `mn`n'' "  95% CI = [" `mn`n''-(1.96*`se`n'') ", " `mn`n''+(1.96*`se`n'')
		
		replace pr = `mn`n'' in `n'
		replace se = `se`n'' in `n'
	}	
	replace party = 51620 in 1
	replace party = 51320 in 2
	replace party = 51420 in 3
	replace party = 51330 in 4
	replace pm = 1 in 1
	replace g = 1 in 1	
	
	drop pr1-se4
	gen N = _N
	drop if _n > 4
	sort ccode year
	save "GB--1985.dta", replace
restore

*** Canada 2006
preserve
	local cc = 20
	local y = 2006
	keep if ccode == `cc' & year == `y'

	qui mlogit vote1 $rhs $y06, base(2) nolog
	
	postfile pr ccode year obs pr1 pr2 pr3 pr4 se1 se2 se3 se4 using "Canada--2006.dta", replace

	keep if e(sample)
	local obs = `e(N)'
	estsimp `e(cmdline)'
	qui foreach n of numlist 1(1)`obs' {
		setx [`n']
		simqi, fd(genpr(pr1 pr2 pr3 pr4)) changex($v)
		foreach p of numlist 1(1)4 {
			qui sum pr`p'
			local pr`p' = r(mean)
			local se`p' = r(sd)
		}
		post pr (`cc') (`y') (`n') (`pr1') (`pr2') (`pr3') (`pr4') (`se1') (`se2') (`se3') (`se4')
		cap drop pr*	
		if mod(`n',50) == 0 {
			nois display "." _c
			if mod(`n',1000) == 0 {
				nois display ""
			}
		}			
	}
	postclose pr
restore

preserve
	use "Canada--2006.dta", clear
	foreach v in party pr se govt pm {
		gen `v' = .
	}	
	foreach n of numlist 1(1)4 {
		qui sum pr`n'
		local mn`n' = r(mean)
		qui sum se`n'
		local se`n' = r(mean)
		di as result "Change in probability for party `n' " = `mn`n'' "  95% CI = [" `mn`n''-(1.96*`se`n'') ", " `mn`n''+(1.96*`se`n'')
		
		replace pr = `mn`n'' in `n'
		replace se = `se`n'' in `n'
	}
	replace party = 62623 in 1
	replace party = 62420 in 2
	replace party = 62320 in 3
	replace party = 62901 in 4
	replace pm = 1 in 1
	replace g = 1 in 1	
	
	drop pr1-se4
	gen N = _N
	drop if _n > 4
	sort ccode year
	save "Canada--2006.dta", replace
restore


*** Canada 1996
preserve
	local cc = 20
	local y = 1996
	keep if ccode == `cc' & year == `y'

	qui mlogit vote1 spend_health_3 spend_defense_3 create_jobs_favor cut_gov_spending_3 male age income_quartile union educ religiosity $y96, base(2) nolog
	
	postfile pr ccode year obs pr1 pr2 pr3 pr4 pr5 se1 se2 se3 se4 se5 using "Canada--1996.dta", replace

	keep if e(sample)
	local obs = `e(N)'
	estsimp `e(cmdline)'
	qui foreach n of numlist 1(1)`obs' {
		setx [`n']
		simqi, fd(genpr(pr1 pr2 pr3 pr4 pr5)) changex($v)
		foreach p of numlist 1(1)5 {
			qui sum pr`p'
			local pr`p' = r(mean)
			local se`p' = r(sd)
		}
		post pr (`cc') (`y') (`n') (`pr1') (`pr2') (`pr3') (`pr4') (`pr5') (`se1') (`se2') (`se3') (`se4') (`se5')
		cap drop pr*	
		if mod(`n',50) == 0 {
			nois display "." _c
			if mod(`n',1000) == 0 {
				nois display ""
			}
		}			
	}
	postclose pr
restore

preserve
	use "Canada--1996.dta", clear
	foreach v in party pr se govt pm {
		gen `v' = .
	}	
	foreach n of numlist 1(1)5 {
		qui sum pr`n'
		local mn`n' = r(mean)
		qui sum se`n'
		local se`n' = r(mean)
		di as result "Change in probability for party `n' " = `mn`n'' "  95% CI = [" `mn`n''-(1.96*`se`n'') ", " `mn`n''+(1.96*`se`n'')
		
		replace pr = `mn`n'' in `n'
		replace se = `se`n'' in `n'
	}	
	replace party = 62420 in 1
	replace party = 62620 in 2
	replace party = 62320 in 3
	replace party = 62901 in 4
	replace party = 62621 in 5
	replace pm = 1 in 1
	replace g = 1 in 1	
	
	drop pr1-se5
	gen N = _N	
	drop if _n > 5
	sort ccode year
	save "Canada--1996.dta", replace
restore

*** US 2006
preserve
	local cc = 2
	local y = 2006
	keep if ccode == `cc' & year == `y'

	recode vote1 (2=0)

	qui logit vote1 $rhs $y06
	
	postfile pr ccode year obs pr0 pr1 se0 se1 using "USA--2006.dta", replace

	keep if e(sample)
	local obs = `e(N)'
	estsimp `e(cmdline)'
	qui foreach n of numlist 1(1)`obs' {
		setx [`n']
		simqi, fd(prval(0 1) genpr(pr0 pr1)) changex($v)
		foreach p of numlist 0(1)1 {
			qui sum pr`p'
			local pr`p' = r(mean)
			local se`p' = r(sd)
		}
		post pr (`cc') (`y') (`n') (`pr0') (`pr1') (`se0') (`se1')
		cap drop pr*	
		if mod(`n',50) == 0 {
			nois display "." _c
			if mod(`n',1000) == 0 {
				nois display ""
			}
		}			
	}
	postclose pr
restore

preserve
	use "USA--2006.dta", clear
	foreach v in party pr se govt pm {
		gen `v' = .
	}	
	foreach n of numlist 0(1)1 {
		qui sum pr`n'
		local mn`n' = r(mean)
		qui sum se`n'
		local se`n' = r(mean)
		di as result "Change in probability for party `n' " = `mn`n'' "  95% CI = [" `mn`n''-(1.96*`se`n'') ", " `mn`n''+(1.96*`se`n'')
		local b = `n' + 1
		replace pr = `mn`n'' in `b'
		replace se = `se`n'' in `b'
	}	
	replace party = 61320 in 1
	replace party = 61620 in 2
	replace pm = 1 in 2
	replace g = 1 in 2	
	
	drop pr0-se1
	gen N = _N	
	drop if _n > 2
	sort ccode year
	save "USA--2006.dta", replace
restore

*** US 1996
preserve
	local cc = 2
	local y = 1996
	keep if ccode == `cc' & year == `y'

	qui mlogit vote1 spend_health_3 spend_defense_3 create_jobs_favor cut_gov_spending_3 male age income_quartile unemployed union educ $y96, base(2) nolog
	
	postfile pr ccode year obs pr1 pr2 pr3 se1 se2 se3 using "USA--1996.dta", replace

	keep if e(sample)
	local obs = `e(N)'
	estsimp `e(cmdline)'
	qui foreach n of numlist 1(1)`obs' {
		setx [`n']
		simqi, fd(prval(1 2 3) genpr(pr1 pr2 pr3)) changex($v)
		foreach p of numlist 1(1)3 {
			qui sum pr`p'
			local pr`p' = r(mean)
			local se`p' = r(sd)
		}
		post pr (`cc') (`y') (`n') (`pr1') (`pr2') (`pr3') (`se1') (`se2') (`se3')
		cap drop pr1 - pr3	
		if mod(`n',50) == 0 {
			nois display "." _c
			if mod(`n',1000) == 0 {
				nois display ""
			}
		}			
	}
	postclose pr
restore

preserve
	use "USA--1996.dta", clear
	foreach v in party pr se govt pm {
		gen `v' = .
	}	
	foreach n of numlist 1(1)3 {
		qui sum pr`n'
		local mn`n' = r(mean)
		qui sum se`n'
		local se`n' = r(mean)
		di as result "Change in probability for party `n' " = `mn`n'' "  95% CI = [" `mn`n''-(1.96*`se`n'') ", " `mn`n''+(1.96*`se`n'')
		local b = `n'
		replace pr = `mn`n'' in `b'
		replace se = `se`n'' in `b'
	}	
	replace party = 61320 in 1
	replace party = 61620 in 2
	replace party = . in 3
	replace pm = 1 in 1
	replace g = 1 in 1	
	
	drop pr1-se3
	gen N = _N	
	drop if _n > 3
	sort ccode year
	save "USA--1996.dta", replace
restore

*** US 1990
preserve
	local cc = 2
	local y = 1990
	keep if ccode == `cc' & year == `y'

	recode vote1 (2=0)

	qui logit vote1 spend_health_3 spend_defense_3 create_jobs_favor cut_gov_spending_3 male age income_quartile unemployed union educ $y90
	
	postfile pr ccode year obs pr0 pr1 se0 se1 using "USA--1990.dta", replace

	keep if e(sample)
	local obs = `e(N)'
	estsimp `e(cmdline)'
	qui foreach n of numlist 1(1)`obs' {
		setx [`n']
		simqi, fd(prval(0 1) genpr(pr0 pr1)) changex($v)
		foreach p of numlist 0(1)1 {
			qui sum pr`p'
			local pr`p' = r(mean)
			local se`p' = r(sd)
		}
		post pr (`cc') (`y') (`n') (`pr0') (`pr1') (`se0') (`se1')
		cap drop pr0 - pr1	
		if mod(`n',50) == 0 {
			nois display "." _c
			if mod(`n',1000) == 0 {
				nois display ""
			}
		}			
	}
	postclose pr
restore

preserve
	use "USA--1990.dta", clear
	foreach v in party pr se govt pm {
		gen `v' = .
	}	
	foreach n of numlist 0(1)1 {
		qui sum pr`n'
		local mn`n' = r(mean)
		qui sum se`n'
		local se`n' = r(mean)
		di as result "Change in probability for party `n' " = `mn`n'' "  95% CI = [" `mn`n''-(1.96*`se`n'') ", " `mn`n''+(1.96*`se`n'')
		local b = `n' + 1
		replace pr = `mn`n'' in `b'
		replace se = `se`n'' in `b'
	}	
	replace party = 61320 in 1
	replace party = 61620 in 2
	replace pm = 1 in 2
	replace g = 1 in 2	
	
	drop pr0-se1
	gen N = _N	
	drop if _n > 2
	sort ccode year
	save "USA--1990.dta", replace
restore

*** US 1985
preserve
	local cc = 2
	local y = 1985
	keep if ccode == `cc' & year == `y'

	recode vote1 (2=0)

	qui logit vote1 $rhs $y85
	
	postfile pr ccode year obs pr0 pr1 se0 se1 using "USA--1985.dta", replace

	keep if e(sample)
	local obs = `e(N)'
	estsimp `e(cmdline)'
	qui foreach n of numlist 1(1)`obs' {
		setx [`n']
		simqi, fd(prval(0 1) genpr(pr0 pr1)) changex($v)
		foreach p of numlist 0(1)1 {
			qui sum pr`p'
			local pr`p' = r(mean)
			local se`p' = r(sd)
		}
		post pr (`cc') (`y') (`n') (`pr0') (`pr1') (`se0') (`se1')
		cap drop pr0 - pr1	
		if mod(`n',50) == 0 {
			nois display "." _c
			if mod(`n',1000) == 0 {
				nois display ""
			}
		}			
	}
	postclose pr
restore

preserve
	use "USA--1985.dta", clear
	foreach v in party pr se govt pm {
		gen `v' = .
	}	
	foreach n of numlist 0(1)1 {
		qui sum pr`n'
		local mn`n' = r(mean)
		qui sum se`n'
		local se`n' = r(mean)
		di as result "Change in probability for party `n' " = `mn`n'' "  95% CI = [" `mn`n''-(1.96*`se`n'') ", " `mn`n''+(1.96*`se`n'')
		local b = `n' + 1
		replace pr = `mn`n'' in `b'
		replace se = `se`n'' in `b'
	}	
	replace party = 61320 in 1
	replace party = 61620 in 2
	replace pm = 1 in 2
	replace g = 1 in 2	
	
	drop pr0-se1
	gen N = _N	
	drop if _n > 2
	sort ccode year
	save "USA--1985.dta", replace
restore

*** Ireland 2005
preserve
	local cc = 205
	local y = 2005
	keep if ccode == `cc' & year == `y'

	recode vote1 (2 6/7=.) (3=2) (5=3)

	qui mlogit vote1 $rhs $y06, base(2) nolog
	
	postfile pr ccode year obs pr1 pr2 pr3 se1 se2 se3 using "Ireland--2005.dta", replace

	keep if e(sample)
	local obs = `e(N)'
	estsimp `e(cmdline)'
	qui foreach n of numlist 1(1)`obs' {
		setx [`n']
		simqi, fd(genpr(pr1 pr2 pr3)) changex($v)
		foreach p of numlist 1(1)3 {
			qui sum pr`p'
			local pr`p' = r(mean)
			local se`p' = r(sd)
		}
		post pr (`cc') (`y') (`n') (`pr1') (`pr2') (`pr3') (`se1') (`se2') (`se3')
		cap drop pr*	
		if mod(`n',50) == 0 {
			nois display "." _c
			if mod(`n',1000) == 0 {
				nois display ""
			}
		}			
	}
	postclose pr
restore

preserve
	use "Ireland--2005.dta", clear
	foreach v in party pr se govt pm {
		gen `v' = .
	}
	foreach n of numlist 1(1)3 {
		qui sum pr`n'
		local mn`n' = r(mean)
		qui sum se`n'
		local se`n' = r(mean)
		di as result "Change in probability for party `n' " = `mn`n'' "  95% CI = [" `mn`n''-(1.96*`se`n'') ", " `mn`n''+(1.96*`se`n'')
		
		replace pr = `mn`n'' in `n'
		replace se = `se`n'' in `n'
	}	
	replace party = 53620 in 1
	replace party = 53320 in 2
	replace party = 53520 in 3
	replace pm = 1 in 1
	replace g = 1 in 1	
	
	drop pr1-se3
	gen N = _N	
	drop if _n > 3
	sort ccode year
	save "Ireland--2005.dta", replace
restore

*** Netherlands 2006
preserve
	local cc = 210
	local y = 2006
	keep if ccode == `cc' & year == `y'

	recode vote1 (6/7=.) (9=6) 
	
	qui mlogit vote1 $rhs $y06, base(2) nolog
	
	postfile pr ccode year obs pr1 pr2 pr3 pr4 pr5 pr6 se1 se2 se3 se4 se5 se6 using "Netherlands--2006.dta", replace

	keep if e(sample)
	local obs = `e(N)'
	estsimp `e(cmdline)'
	qui foreach n of numlist 1(1)`obs' {
		setx [`n']
		simqi, fd(genpr(pr1 pr2 pr3 pr4 pr5 pr6)) changex($v)
		foreach p of numlist 1(1)6 {
			qui sum pr`p'
			local pr`p' = r(mean)
			local se`p' = r(sd)
		}
		post pr (`cc') (`y') (`n') (`pr1') (`pr2') (`pr3') (`pr4') (`pr5') (`pr6') (`se1') (`se2') (`se3') (`se4') (`se5') (`se6')
		cap drop pr*	
		if mod(`n',50) == 0 {
			nois display "." _c
			if mod(`n',1000) == 0 {
				nois display ""
			}
		}			
	}
	postclose pr
restore

preserve
	use "Netherlands--2006.dta", clear
	foreach v in party pr se govt pm {
		gen `v' = .
	}	
	foreach n of numlist 1(1)6 {
		qui sum pr`n'
		local mn`n' = r(mean)
		qui sum se`n'
		local se`n' = r(mean)
		di as result "Change in probability for party `n' " = `mn`n'' "  95% CI = [" `mn`n''-(1.96*`se`n'') ", " `mn`n''+(1.96*`se`n'')
		
		replace pr = `mn`n'' in `n'
		replace se = `se`n'' in `n'
	}	
	replace party = 22521 in 1
	replace party = 22420 in 2
	replace party = 22320 in 3
	replace party = 22220 in 4
	replace party = 22110 in 5
	replace party = 22526 in 6
	replace pm = 1 in 1
	replace g = 1 in 1/2	
	
	drop pr1-se6
	gen N = _N	
	drop if _n > 6
	sort ccode year
	save "Netherlands--2006.dta", replace
restore

*** France 1997
preserve
	local cc = 220
	local y = 1997
	keep if ccode == `cc' & year == `y'

	recode vote1 (4=3) (5=4) (6=5) (7=6)
	
	qui mlogit vote1 $rhs $y96, base(2) nolog
	
	postfile pr ccode year obs pr1 pr2 pr3 pr4 pr5 pr6 se1 se2 se3 se4 se5 se6 using "France--1997.dta", replace

	keep if e(sample)
	local obs = `e(N)'
	estsimp `e(cmdline)'
	qui foreach n of numlist 1(1)`obs' {
		setx [`n']
		simqi, fd(genpr(pr1 pr2 pr3 pr4 pr5 pr6)) changex($v)
		foreach p of numlist 1(1)6 {
			qui sum pr`p'
			local pr`p' = r(mean)
			local se`p' = r(sd)
		}
		post pr (`cc') (`y') (`n') (`pr1') (`pr2') (`pr3') (`pr4') (`pr5') (`pr6') (`se1') (`se2') (`se3') (`se4') (`se5') (`se6')
		cap drop pr*	
		if mod(`n',50) == 0 {
			nois display "." _c
			if mod(`n',1000) == 0 {
				nois display ""
			}
		}			
	}
	postclose pr
restore

preserve
	use "France--1997.dta", clear
	foreach v in party pr se govt pm {
		gen `v' = .
	}	
	foreach n of numlist 1(1)6 {
		qui sum pr`n'
		local mn`n' = r(mean)
		qui sum se`n'
		local se`n' = r(mean)
		di as result "Change in probability for party `n' " = `mn`n'' "  95% CI = [" `mn`n''-(1.96*`se`n'') ", " `mn`n''+(1.96*`se`n'')
		
		replace pr = `mn`n'' in `n'
		replace se = `se`n'' in `n'
	}	
	replace party = 31320 in 1
	replace party = 31220 in 2
	replace party = 31110 in 3
	replace party = 31624 in 4
	replace party = 31625 in 5
	replace party = 31720 in 6
	replace pm = 1 in 1
	replace g = 1 in 1/3	
	
	drop pr1-se6
	gen N = _N	
	drop if _n > 6
	sort ccode year
	save "France--1997.dta", replace
restore

*** France 2006
preserve
	local cc = 220
	local y = 2006
	keep if ccode == `cc' & year == `y'

	recode vote1 (5=.) (6=5) (7=6)
	
	qui mlogit vote1 $rhs $y06, base(2) nolog
	
	postfile pr ccode year obs pr1 pr2 pr3 pr4 pr5 pr6 se1 se2 se3 se4 se5 se6 using "France--2006.dta", replace

	keep if e(sample)
	local obs = `e(N)'
	estsimp `e(cmdline)'
	qui foreach n of numlist 1(1)`obs' {
		setx [`n']
		simqi, fd(genpr(pr1 pr2 pr3 pr4 pr5 pr6)) changex($v)
		foreach p of numlist 1(1)6 {
			qui sum pr`p'
			local pr`p' = r(mean)
			local se`p' = r(sd)
		}
		post pr (`cc') (`y') (`n') (`pr1') (`pr2') (`pr3') (`pr4') (`pr5') (`pr6') (`se1') (`se2') (`se3') (`se4') (`se5') (`se6')
		cap drop pr*	
		if mod(`n',50) == 0 {
			nois display "." _c
			if mod(`n',1000) == 0 {
				nois display ""
			}
		}			
	}
	postclose pr
restore

preserve
	use "France--2006.dta", clear
	foreach v in party pr se govt pm {
		gen `v' = .
	}	
	foreach n of numlist 1(1)6 {
		qui sum pr`n'
		local mn`n' = r(mean)
		qui sum se`n'
		local se`n' = r(mean)
		di as result "Change in probability for party `n' " = `mn`n'' "  95% CI = [" `mn`n''-(1.96*`se`n'') ", " `mn`n''+(1.96*`se`n'')
		
		replace pr = `mn`n'' in `n'
		replace se = `se`n'' in `n'
	}	
	replace party = 31626 in 1
	replace party = 31624 in 2
	replace party = 31320 in 3
	replace party = 31110 in 4
	replace party = 31220 in 5
	replace party = 31720 in 6
	replace pm = 1 in 1
	replace g = 1 in 1/2	
	
	drop pr1-se6
	gen N = _N	
	drop if _n > 6
	sort ccode year
	save "France--2006.dta", replace
restore

*** Switzerland 1998
preserve
	local cc = 225
	local y = 1998
	keep if ccode == `cc' & year == `y'

	recode vote1 (5/9=.) (10=5) (13=6)
	
	qui mlogit vote1 $rhs redistribute_agree, base(2) nolog
	
	postfile pr ccode year obs pr1 pr2 pr3 pr4 pr5 pr6 se1 se2 se3 se4 se5 se6 using "Switzerland--1998.dta", replace

	keep if e(sample)
	local obs = `e(N)'
	estsimp `e(cmdline)'
	qui foreach n of numlist 1(1)`obs' {
		setx [`n']
		simqi, fd(genpr(pr1 pr2 pr3 pr4 pr5 pr6)) changex($v)
		foreach p of numlist 1(1)6 {
			qui sum pr`p'
			local pr`p' = r(mean)
			local se`p' = r(sd)
		}
		post pr (`cc') (`y') (`n') (`pr1') (`pr2') (`pr3') (`pr4') (`pr5') (`pr6') (`se1') (`se2') (`se3') (`se4') (`se5') (`se6')
		cap drop pr*	
		if mod(`n',50) == 0 {
			nois display "." _c
			if mod(`n',1000) == 0 {
				nois display ""
			}
		}			
	}
	postclose pr
restore

preserve
	use "Switzerland--1998.dta", clear
	foreach v in party pr se govt pm {
		gen `v' = .
	}	
	foreach n of numlist 1(1)6 {
		qui sum pr`n'
		local mn`n' = r(mean)
		qui sum se`n'
		local se`n' = r(mean)
		di as result "Change in probability for party `n' " = `mn`n'' "  95% CI = [" `mn`n''-(1.96*`se`n'') ", " `mn`n''+(1.96*`se`n'')
		
		replace pr = `mn`n'' in `n'
		replace se = `se`n'' in `n'
	}	
	replace party = 43520 in 1
	replace party = 43420 in 2
	replace party = 43320 in 3
	replace party = 43810 in 4
	replace party = 43110 in 5
	replace party = 43531 in 6
	replace pm = 1 in 1
	replace g = 1 in 1/4	
	
	drop pr1-se6
	gen N = _N	
	drop if _n > 6
	sort ccode year
	save "Switzerland--1998.dta", replace
restore

*** Switzerland 2007
preserve
	local cc = 225
	local y = 2007
	keep if ccode == `cc' & year == `y'

	recode vote1 (5/9=.) (10=5)
	
	qui mlogit vote1 $rhs $y06, base(2) nolog
	
	postfile pr ccode year obs pr1 pr2 pr3 pr4 pr5 se1 se2 se3 se4 se5 using "Switzerland--2007.dta", replace

	keep if e(sample)
	local obs = `e(N)'
	estsimp `e(cmdline)'
	qui foreach n of numlist 1(1)`obs' {
		setx [`n']
		simqi, fd(genpr(pr1 pr2 pr3 pr4 pr5)) changex($v)
		foreach p of numlist 1(1)5 {
			qui sum pr`p'
			local pr`p' = r(mean)
			local se`p' = r(sd)
		}
		post pr (`cc') (`y') (`n') (`pr1') (`pr2') (`pr3') (`pr4') (`pr5') (`se1') (`se2') (`se3') (`se4') (`se5')
		cap drop pr*	
		if mod(`n',50) == 0 {
			nois display "." _c
			if mod(`n',1000) == 0 {
				nois display ""
			}
		}			
	}
	postclose pr
restore

preserve
	use "Switzerland--2007.dta", clear
	foreach v in party pr se govt pm {
		gen `v' = .
	}	
	foreach n of numlist 1(1)5 {
		qui sum pr`n'
		local mn`n' = r(mean)
		qui sum se`n'
		local se`n' = r(mean)
		di as result "Change in probability for party `n' " = `mn`n'' "  95% CI = [" `mn`n''-(1.96*`se`n'') ", " `mn`n''+(1.96*`se`n'')
		
		replace pr = `mn`n'' in `n'
		replace se = `se`n'' in `n'
	}	
	replace party = 43320 in 1
	replace party = 43810 in 2
	replace party = 43420 in 3
	replace party = 43520 in 4
	replace party = 43110 in 5
	replace pm = 1 in 1
	replace g = 1 in 1/4	
	
	drop pr1-se5
	gen N = _N	
	drop if _n > 5
	sort ccode year
	save "Switzerland--2007.dta", replace
restore

*** Spain 2006
preserve
	local cc = 230
	local y = 2006
	keep if ccode == `cc' & year == `y'

	recode vote1 (6/10=.)
	
	qui mlogit vote1 $rhs $y06, base(2) nolog
	
	postfile pr ccode year obs pr1 pr2 pr3 pr4 pr5 se1 se2 se3 se4 se5 using "Spain--2006.dta", replace

	keep if e(sample)
	local obs = `e(N)'
	estsimp `e(cmdline)'
	qui foreach n of numlist 1(1)`obs' {
		setx [`n']
		simqi, fd(genpr(pr1 pr2 pr3 pr4 pr5)) changex($v)
		foreach p of numlist 1(1)5 {
			qui sum pr`p'
			local pr`p' = r(mean)
			local se`p' = r(sd)
		}
		post pr (`cc') (`y') (`n') (`pr1') (`pr2') (`pr3') (`pr4') (`pr5') (`se1') (`se2') (`se3') (`se4') (`se5')
		cap drop pr*	
		if mod(`n',50) == 0 {
			nois display "." _c
			if mod(`n',1000) == 0 {
				nois display ""
			}
		}			
	}
	postclose pr
restore

preserve
	use "Spain--2006.dta", clear
	foreach v in party pr se govt pm {
		gen `v' = .
	}	
	foreach n of numlist 1(1)5 {
		qui sum pr`n'
		local mn`n' = r(mean)
		qui sum se`n'
		local se`n' = r(mean)
		di as result "Change in probability for party `n' " = `mn`n'' "  95% CI = [" `mn`n''-(1.96*`se`n'') ", " `mn`n''+(1.96*`se`n'')
		
		replace pr = `mn`n'' in `n'
		replace se = `se`n'' in `n'
	}	
	replace party = 33320 in 1
	replace party = 33610 in 2
	replace party = 33220 in 3
	replace party = 33611 in 4
	replace party = 33905 in 5
	replace pm = 1 in 1
	replace g = 1 in 1	
	
	drop pr1-se5
	gen N = _N	
	drop if _n > 5
	sort ccode year
	save "Spain--2006.dta", replace
restore

*** Portugal 2006
preserve
	local cc = 235
	local y = 2006
	keep if ccode == `cc' & year == `y'

	recode vote1 (2=.) (10=4) (11=2)
	
	qui mlogit vote1 $rhs $y06, base(2) nolog
	
	postfile pr ccode year obs pr1 pr2 pr3 pr4 se1 se2 se3 se4 using "Portugal--2006.dta", replace

	keep if e(sample)
	local obs = `e(N)'
	estsimp `e(cmdline)'
	qui foreach n of numlist 1(1)`obs' {
		setx [`n']
		simqi, fd(genpr(pr1 pr2 pr3 pr4)) changex($v)
		foreach p of numlist 1(1)4 {
			qui sum pr`p'
			local pr`p' = r(mean)
			local se`p' = r(sd)
		}
		post pr (`cc') (`y') (`n') (`pr1') (`pr2') (`pr3') (`pr4') (`se1') (`se2') (`se3') (`se4')
		cap drop pr*	
		if mod(`n',50) == 0 {
			nois display "." _c
			if mod(`n',1000) == 0 {
				nois display ""
			}
		}			
	}
	postclose pr
restore

preserve
	use "Portugal--2006.dta", clear
	foreach v in party pr se govt pm {
		gen `v' = .
	}	
	foreach n of numlist 1(1)4 {
		qui sum pr`n'
		local mn`n' = r(mean)
		qui sum se`n'
		local se`n' = r(mean)
		di as result "Change in probability for party `n' " = `mn`n'' "  95% CI = [" `mn`n''-(1.96*`se`n'') ", " `mn`n''+(1.96*`se`n'')
		
		replace pr = `mn`n'' in `n'
		replace se = `se`n'' in `n'
	}	
	replace party = 35311 in 1
	replace party = 35211 in 2
	replace party = 35229 in 3
	replace party = 35313 in 4
	replace pm = 1 in 1
	replace g = 1 in 1	
	
	drop pr1-se4
	gen N = _N	
	drop if _n > 4
	sort ccode year
	save "Portugal--2006.dta", replace
restore

*** Germany 1985
preserve
	local cc = 255
	local y = 1985
	keep if ccode == `cc' & year == `y'

	qui mlogit vote1 $rhs $y86, base(2) nolog
	
	postfile pr ccode year obs pr1 pr2 pr3 pr4 se1 se2 se3 se4 using "Germany--1985.dta", replace

	keep if e(sample)
	local obs = `e(N)'
	estsimp `e(cmdline)'
	qui foreach n of numlist 1(1)`obs' {
		setx [`n']
		simqi, fd(genpr(pr1 pr2 pr3 pr4)) changex($v)
		foreach p of numlist 1(1)4 {
			qui sum pr`p'
			local pr`p' = r(mean)
			local se`p' = r(sd)
		}
		post pr (`cc') (`y') (`n') (`pr1') (`pr2') (`pr3') (`pr4') (`se1') (`se2') (`se3') (`se4')
		cap drop pr1 - pr4	
		if mod(`n',50) == 0 {
			nois display "." _c
			if mod(`n',1000) == 0 {
				nois display ""
			}
		}			
	}
	postclose pr
restore

preserve
	use "Germany--1985.dta", clear
	foreach v in party pr se govt pm {
		gen `v' = .
	}	
	foreach n of numlist 1(1)4 {
		qui sum pr`n'
		local mn`n' = r(mean)
		qui sum se`n'
		local se`n' = r(mean)
		di as result "Change in probability for party `n' " = `mn`n'' "  95% CI = [" `mn`n''-(1.96*`se`n'') ", " `mn`n''+(1.96*`se`n'')
		
		replace pr = `mn`n'' in `n'
		replace se = `se`n'' in `n'
	}	
	replace party = 41521 in 1
	replace party = 41111 in 2
	replace party = 41320 in 3
	replace party = 41420 in 4
	replace pm = 1 in 1
	replace g = 1 if _n == 1 | _n == 4
	
	drop pr1-se4
	gen N = _N	
	drop if _n > 4
	sort ccode year
	save "Germany--1985.dta", replace
restore

*** Germany 1990
preserve
	local cc = 255
	local y = 1990
	keep if ccode == `cc' & year == `y'

	qui mlogit vote1 $rhs $y90, base(2) nolog
	
	postfile pr ccode year obs pr1 pr2 pr3 pr4 se1 se2 se3 se4 using "Germany--1990.dta", replace

	keep if e(sample)
	local obs = `e(N)'
	estsimp `e(cmdline)'
	qui foreach n of numlist 1(1)`obs' {
		setx [`n']
		simqi, fd(genpr(pr1 pr2 pr3 pr4)) changex($v)
		foreach p of numlist 1(1)4 {
			qui sum pr`p'
			local pr`p' = r(mean)
			local se`p' = r(sd)
		}
		post pr (`cc') (`y') (`n') (`pr1') (`pr2') (`pr3') (`pr4') (`se1') (`se2') (`se3') (`se4')
		cap drop pr1 - pr4	
		if mod(`n',50) == 0 {
			nois display "." _c
			if mod(`n',1000) == 0 {
				nois display ""
			}
		}			
	}
	postclose pr
restore

preserve
	use "Germany--1990.dta", clear
	foreach v in party pr se govt pm {
		gen `v' = .
	}	
	foreach n of numlist 1(1)4 {
		qui sum pr`n'
		local mn`n' = r(mean)
		qui sum se`n'
		local se`n' = r(mean)
		di as result "Change in probability for party `n' " = `mn`n'' "  95% CI = [" `mn`n''-(1.96*`se`n'') ", " `mn`n''+(1.96*`se`n'')
		
		replace pr = `mn`n'' in `n'
		replace se = `se`n'' in `n'
	}	
	replace party = 41521 in 1
	replace party = 41420 in 2
	replace party = 41320 in 3
	replace party = 41111 in 4
	replace pm = 1 in 1
	replace g = 1 in 1/2	
	
	drop pr1-se4
	gen N = _N	
	drop if _n > 4
	sort ccode year
	save "Germany--1990.dta", replace
restore

*** Germany 1996
preserve
	local cc = 255
	local y = 1996
	keep if ccode == `cc' & year == `y'

	recode vote1 (8=.)
	
	qui mlogit vote1 $rhs $y96, base(2) nolog
	
	postfile pr ccode year obs pr1 pr2 pr3 pr4 se1 se2 se3 se4 using "Germany--1996.dta", replace

	keep if e(sample)
	local obs = `e(N)'
	estsimp `e(cmdline)'
	qui foreach n of numlist 1(1)`obs' {
		setx [`n']
		simqi, fd(genpr(pr1 pr2 pr3 pr4)) changex($v)
		foreach p of numlist 1(1)4 {
			qui sum pr`p'
			local pr`p' = r(mean)
			local se`p' = r(sd)
		}
		post pr (`cc') (`y') (`n') (`pr1') (`pr2') (`pr3') (`pr4') (`se1') (`se2') (`se3') (`se4')
		cap drop pr*	
		if mod(`n',50) == 0 {
			nois display "." _c
			if mod(`n',1000) == 0 {
				nois display ""
			}
		}			
	}
	postclose pr
restore

preserve
	use "Germany--1996.dta", clear
	foreach v in party pr se govt pm {
		gen `v' = .
	}	
	foreach n of numlist 1(1)4 {
		qui sum pr`n'
		local mn`n' = r(mean)
		qui sum se`n'
		local se`n' = r(mean)
		di as result "Change in probability for party `n' " = `mn`n'' "  95% CI = [" `mn`n''-(1.96*`se`n'') ", " `mn`n''+(1.96*`se`n'')
		
		replace pr = `mn`n'' in `n'
		replace se = `se`n'' in `n'
	}	
	replace party = 41521 in 1
	replace party = 41420 in 2
	replace party = 41320 in 3
	replace party = 41113 in 4
	replace pm = 1 in 1
	replace g = 1 in 1/2	
	
	drop pr1-se4
	gen N = _N	
	drop if _n > 4
	sort ccode year
	save "Germany--1996.dta", replace
restore

*** Germany 2006
preserve
	local cc = 255
	local y = 2006
	keep if ccode == `cc' & year == `y'

	recode vote1 (8=5)
	
	qui mlogit vote1 $rhs $y06, base(2) nolog
	
	postfile pr ccode year obs pr1 pr2 pr3 pr4 pr5 se1 se2 se3 se4 se5 using "Germany--2006.dta", replace

	keep if e(sample)
	local obs = `e(N)'
	estsimp `e(cmdline)'
	qui foreach n of numlist 1(1)`obs' {
		setx [`n']
		simqi, fd(genpr(pr1 pr2 pr3 pr4 pr5)) changex($v)
		foreach p of numlist 1(1)5 {
			qui sum pr`p'
			local pr`p' = r(mean)
			local se`p' = r(sd)
		}
		post pr (`cc') (`y') (`n') (`pr1') (`pr2') (`pr3') (`pr4') (`pr5') (`se1') (`se2') (`se3') (`se4') (`se5')
		cap drop pr*	
		if mod(`n',50) == 0 {
			nois display "." _c
			if mod(`n',1000) == 0 {
				nois display ""
			}
		}			
	}
	postclose pr
restore

preserve
	use "Germany--2006.dta", clear
	foreach v in party pr se govt pm {
		gen `v' = .
	}	
	foreach n of numlist 1(1)5 {
		qui sum pr`n'
		local mn`n' = r(mean)
		qui sum se`n'
		local se`n' = r(mean)
		di as result "Change in probability for party `n' " = `mn`n'' "  95% CI = [" `mn`n''-(1.96*`se`n'') ", " `mn`n''+(1.96*`se`n'')
		
		replace pr = `mn`n'' in `n'
		replace se = `se`n'' in `n'
	}	
	replace party = 41521 in 1
	replace party = 41320 in 2
	replace party = 41420 in 3
	replace party = 41113 in 4
	replace party = 41222 in 5
	replace pm = 1 in 1
	replace g = 1 in 1/2	
	
	drop pr1-se5
	gen N = _N	
	drop if _n > 5
	sort ccode year
	save "Germany--2006.dta", replace
restore

*** Poland 1997
preserve
	local cc = 290
	local y = 1997
	keep if ccode == `cc' & year == `y'

	recode vote1 (9=.) (6=4) (7=5)
	
	qui mlogit vote1 $rhs $y96, base(2) nolog
	
	postfile pr ccode year obs pr1 pr2 pr3 pr4 pr5 se1 se2 se3 se4 se5 using "Poland--1997.dta", replace

	keep if e(sample)
	local obs = `e(N)'
	estsimp `e(cmdline)'
	qui foreach n of numlist 1(1)`obs' {
		setx [`n']
		simqi, fd(genpr(pr1 pr2 pr3 pr4 pr5)) changex($v)
		foreach p of numlist 1(1)5 {
			qui sum pr`p'
			local pr`p' = r(mean)
			local se`p' = r(sd)
		}
		post pr (`cc') (`y') (`n') (`pr1') (`pr2') (`pr3') (`pr4') (`pr5') (`se1') (`se2') (`se3') (`se4') (`se5')
		cap drop pr*	
		if mod(`n',50) == 0 {
			nois display "." _c
			if mod(`n',1000) == 0 {
				nois display ""
			}
		}			
	}
	postclose pr
restore

preserve
	use "Poland--1997.dta", clear
	foreach v in party pr se govt pm {
		gen `v' = .
	}	
	foreach n of numlist 1(1)5 {
		qui sum pr`n'
		local mn`n' = r(mean)
		qui sum se`n'
		local se`n' = r(mean)
		di as result "Change in probability for party `n' " = `mn`n'' "  95% CI = [" `mn`n''-(1.96*`se`n'') ", " `mn`n''+(1.96*`se`n'')
		
		replace pr = `mn`n'' in `n'
		replace se = `se`n'' in `n'
	}	
	replace party = 92620 in 1
	replace party = 92434 in 2
	replace party = 92322 in 3
	replace party = 92210 in 4
	replace party = 92811 in 5
	replace pm = 1 in 1
	replace g = 1 in 1/2	
	
	drop pr1-se5
	gen N = _N	
	drop if _n > 5
	sort ccode year
	save "Poland--1997.dta", replace
restore

*** Poland 2008
preserve
	local cc = 290
	local y = 2008
	keep if ccode == `cc' & year == `y'

	recode vote1 (3=.) (8=3) (7=4)
	
	qui mlogit vote1 $rhs $y06, base(2) nolog
	
	postfile pr ccode year obs pr1 pr2 pr3 pr4 se1 se2 se3 se4 using "Poland--2008.dta", replace

	keep if e(sample)
	local obs = `e(N)'
	estsimp `e(cmdline)'
	qui foreach n of numlist 1(1)`obs' {
		setx [`n']
		simqi, fd(genpr(pr1 pr2 pr3 pr4)) changex($v)
		foreach p of numlist 1(1)4 {
			qui sum pr`p'
			local pr`p' = r(mean)
			local se`p' = r(sd)
		}
		post pr (`cc') (`y') (`n') (`pr1') (`pr2') (`pr3') (`pr4') (`se1') (`se2') (`se3') (`se4')
		cap drop pr*	
		if mod(`n',50) == 0 {
			nois display "." _c
			if mod(`n',1000) == 0 {
				nois display ""
			}
		}			
	}
	postclose pr
restore

preserve
	use "Poland--2008.dta", clear
	foreach v in party pr se govt pm {
		gen `v' = .
	}	
	foreach n of numlist 1(1)4 {
		qui sum pr`n'
		local mn`n' = r(mean)
		qui sum se`n'
		local se`n' = r(mean)
		di as result "Change in probability for party `n' " = `mn`n'' "  95% CI = [" `mn`n''-(1.96*`se`n'') ", " `mn`n''+(1.96*`se`n'')
		
		replace pr = `mn`n'' in `n'
		replace se = `se`n'' in `n'
	}	
	replace party = 92435 in 1
	replace party = 92811 in 2
	replace party = 92436 in 3
	replace party = 92021 in 4
	replace pm = 1 in 1
	replace g = 1 in 1/2	
	
	drop pr1-se4
	gen N = _N	
	drop if _n > 4
	sort ccode year
	save "Poland--2008.dta", replace
restore

*** Austria 1986
preserve
	local cc = 305
	local y = 1986
	keep if ccode == `cc' & year == `y'

	recode vote1 (3=0) (2=.)

	qui logit vote1 spend_health_3 spend_defense_3 create_jobs_favor cut_gov_spending_3 male age income_quartile unemployed union educ religiosity $y86
	
	postfile pr ccode year obs pr0 pr1 se0 se1 using "Austria--1986.dta", replace

	keep if e(sample)
	local obs = `e(N)'
	estsimp `e(cmdline)'
	qui foreach n of numlist 1(1)`obs' {
		setx [`n']
		simqi, fd(prval(0 1) genpr(pr0 pr1)) changex($v)
		foreach p of numlist 0(1)1 {
			qui sum pr`p'
			local pr`p' = r(mean)
			local se`p' = r(sd)
		}
		post pr (`cc') (`y') (`n') (`pr0') (`pr1') (`se0') (`se1')
		cap drop pr0 pr1	
		if mod(`n',50) == 0 {
			nois display "." _c
			if mod(`n',1000) == 0 {
				nois display ""
			}
		}			
	}
	postclose pr
restore

preserve
	use "Austria--1986.dta", clear
	foreach v in party pr se govt pm {
		gen `v' = .
	}	
	foreach n of numlist 0(1)1 {
		qui sum pr`n'
		local mn`n' = r(mean)
		qui sum se`n'
		local se`n' = r(mean)
		di as result "Change in probability for party `n' " = `mn`n'' "  95% CI = [" `mn`n''-(1.96*`se`n'') ", " `mn`n''+(1.96*`se`n'')
		local b = `n' + 1
		replace pr = `mn`n'' in `b'
		replace se = `se`n'' in `b'
	}	
	replace party = 42520 in 1
	replace party = 42320 in 2
	replace pm = 1 in 2
	replace g = 1 in 2
	
	drop pr0-se1
	gen N = _N	
	drop if _n > 2
	sort ccode year
	save "Austria--1986.dta", replace
restore

*** Hungary 1990
preserve
	local cc = 310
	local y = 1990
	keep if ccode == `cc' & year == `y'

	recode vote1 (7=.)
	
	qui mlogit vote1 spend_health_3 spend_defense_3 create_jobs_favor cut_gov_spending_3 male age income_quartile public_employee_d educ religiosity own_home progressive_tax_agree, base(2) nolog
	
	postfile pr ccode year obs pr1 pr2 pr3 pr4 pr5 pr6 se1 se2 se3 se4 se5 se6 using "Hungary--1990.dta", replace

	keep if e(sample)
	local obs = `e(N)'
	estsimp `e(cmdline)'
	qui foreach n of numlist 1(1)`obs' {
		setx [`n']
		simqi, fd(genpr(pr1 pr2 pr3 pr4 pr5 pr6)) changex($v)
		foreach p of numlist 1(1)6 {
			qui sum pr`p'
			local pr`p' = r(mean)
			local se`p' = r(sd)
		}
		post pr (`cc') (`y') (`n') (`pr1') (`pr2') (`pr3') (`pr4') (`pr5') (`pr6') (`se1') (`se2') (`se3') (`se4') (`se5') (`se6')
		cap drop pr1 - pr6	
		if mod(`n',50) == 0 {
			nois display "." _c
			if mod(`n',1000) == 0 {
				nois display ""
			}
		}			
	}
	postclose pr
restore

preserve
	use "Hungary--1990.dta", clear
	foreach v in party pr se govt pm {
		gen `v' = .
	}	
	foreach n of numlist 1(1)6 {
		qui sum pr`n'
		local mn`n' = r(mean)
		qui sum se`n'
		local se`n' = r(mean)
		di as result "Change in probability for party `n' " = `mn`n'' "  95% CI = [" `mn`n''-(1.96*`se`n'') ", " `mn`n''+(1.96*`se`n'')
		
		replace pr = `mn`n'' in `n'
		replace se = `se`n'' in `n'
	}	
	replace party = 86521 in 1
	replace party = 86810 in 2
	replace party = 86421 in 3
	replace party = 86422 in 4
	replace party = 86220 in 5
	replace party = 86522 in 6
	replace pm = 1 in 1
	replace g = 1 in 1/3	
	
	drop pr1-se6
	gen N = _N	
	drop if _n > 6
	sort ccode year
	save "Hungary--1990.dta", replace
restore

*** Hungary 1996
preserve
	local cc = 310
	local y = 1996
	keep if ccode == `cc' & year == `y'

	recode vote1 (9=.)
	
	qui mlogit vote1 $rhs $y96, base(2) nolog
	
	postfile pr ccode year obs pr1 pr2 pr3 pr4 pr5 pr6 se1 se2 se3 se4 se5 se6 using "Hungary--1996.dta", replace

	keep if e(sample)
	local obs = `e(N)'
	estsimp `e(cmdline)'
	qui foreach n of numlist 1(1)`obs' {
		setx [`n']
		simqi, fd(genpr(pr1 pr2 pr3 pr4 pr5 pr6)) changex($v)
		foreach p of numlist 1(1)6 {
			qui sum pr`p'
			local pr`p' = r(mean)
			local se`p' = r(sd)
		}
		post pr (`cc') (`y') (`n') (`pr1') (`pr2') (`pr3') (`pr4') (`pr5') (`pr6') (`se1') (`se2') (`se3') (`se4') (`se5') (`se6')
		cap drop pr*	
		if mod(`n',50) == 0 {
			nois display "." _c
			if mod(`n',1000) == 0 {
				nois display ""
			}
		}			
	}
	postclose pr
restore

preserve
	use "Hungary--1996.dta", clear
	foreach v in party pr se govt pm {
		gen `v' = .
	}	
	foreach n of numlist 1(1)6 {
		qui sum pr`n'
		local mn`n' = r(mean)
		qui sum se`n'
		local se`n' = r(mean)
		di as result "Change in probability for party `n' " = `mn`n'' "  95% CI = [" `mn`n''-(1.96*`se`n'') ", " `mn`n''+(1.96*`se`n'')
		
		replace pr = `mn`n'' in `n'
		replace se = `se`n'' in `n'
	}	
	replace party = 86220 in 1
	replace party = 86422 in 2
	replace party = 86521 in 3
	replace party = 86421 in 4
	replace party = 86522 in 5
	replace party = 86810 in 6
	replace pm = 1 in 1
	replace g = 1 in 1/2	
	
	drop pr1-se6
	gen N = _N	
	drop if _n > 6
	sort ccode year
	save "Hungary--1996.dta", replace
restore

*** Hungary 2006
preserve
	local cc = 310
	local y = 2006
	keep if ccode == `cc' & year == `y'

	recode vote1 (3/4=.) (5=3)
	
	qui mlogit vote1 spend_health_3 spend_defense_3 create_jobs_favor cut_gov_spending_3 male age income_quartile public_employee_d religiosity $y06, base(2) nolog
	
	postfile pr ccode year obs pr1 pr2 pr3 se1 se2 se3 using "Hungary--2006.dta", replace

	keep if e(sample)
	local obs = `e(N)'
	estsimp `e(cmdline)'
	qui foreach n of numlist 1(1)`obs' {
		setx [`n']
		simqi, fd(genpr(pr1 pr2 pr3)) changex($v)
		foreach p of numlist 1(1)3 {
			qui sum pr`p'
			local pr`p' = r(mean)
			local se`p' = r(sd)
		}
		post pr (`cc') (`y') (`n') (`pr1') (`pr2') (`pr3') (`se1') (`se2') (`se3')
		cap drop pr*	
		if mod(`n',50) == 0 {
			nois display "." _c
			if mod(`n',1000) == 0 {
				nois display ""
			}
		}			
	}
	postclose pr
restore

preserve
	use "Hungary--2006.dta", clear
	foreach v in party pr se govt pm {
		gen `v' = .
	}	
	foreach n of numlist 1(1)3 {
		qui sum pr`n'
		local mn`n' = r(mean)
		qui sum se`n'
		local se`n' = r(mean)
		di as result "Change in probability for party `n' " = `mn`n'' "  95% CI = [" `mn`n''-(1.96*`se`n'') ", " `mn`n''+(1.96*`se`n'')
		
		replace pr = `mn`n'' in `n'
		replace se = `se`n'' in `n'
	}	
	replace party = 86429 in 1
	replace party = 86422 in 2
	replace party = 86429 in 3
	replace pm = 1 in 1
	replace g = 1 in 1/2	
	
	drop pr1-se3
	gen N = _N	
	drop if _n > 3
	sort ccode year
	save "Hungary--2006.dta", replace
restore

*** Czech Republic 1996
preserve
	local cc = 316
	local y = 1996
	keep if ccode == `cc' & year == `y'

	recode vote1 (5=4) (9=.) (13=5) (14=6)
	
	qui mlogit vote1 spend_health_3 spend_defense_3 create_jobs_favor cut_gov_spending_3 male age income_quartile public_employee_d union educ $y96, base(2) nolog
	
	postfile pr ccode year obs pr1 pr2 pr3 pr4 pr5 pr6 se1 se2 se3 se4 se5 se6 using "Czech--1996.dta", replace

	keep if e(sample)
	local obs = `e(N)'
	estsimp `e(cmdline)'
	qui foreach n of numlist 1(1)`obs' {
		setx [`n']
		simqi, fd(genpr(pr1 pr2 pr3 pr4 pr5 pr6)) changex($v)
		foreach p of numlist 1(1)6 {
			qui sum pr`p'
			local pr`p' = r(mean)
			local se`p' = r(sd)
		}
		post pr (`cc') (`y') (`n') (`pr1') (`pr2') (`pr3') (`pr4') (`pr5') (`pr6') (`se1') (`se2') (`se3') (`se4') (`se5') (`se6')
		cap drop pr*	
		if mod(`n',50) == 0 {
			nois display "." _c
			if mod(`n',1000) == 0 {
				nois display ""
			}
		}			
	}
	postclose pr
restore

preserve
	use "Czech--1996.dta", clear
	foreach v in party pr se govt pm {
		gen `v' = .
	}	
	foreach n of numlist 1(1)6 {
		qui sum pr`n'
		local mn`n' = r(mean)
		qui sum se`n'
		local se`n' = r(mean)
		di as result "Change in probability for party `n' " = `mn`n'' "  95% CI = [" `mn`n''-(1.96*`se`n'') ", " `mn`n''+(1.96*`se`n'')
		
		replace pr = `mn`n'' in `n'
		replace se = `se`n'' in `n'
	}	
	replace party = 82413 in 1
	replace party = 82523 in 2
	replace party = 82412 in 3
	replace party = 82320 in 4
	replace party = 82220 in 5
	replace party = 82710 in 6
	replace pm = 1 in 1
	replace g = 1 in 1/3	
	
	drop pr1-se6
	gen N = _N	
	drop if _n > 6
	sort ccode year
	save "Czech--1996.dta", replace
restore

*** Czech Republic 2006
preserve
	local cc = 316
	local y = 2006
	keep if ccode == `cc' & year == `y'

	recode vote1 (10=2) (18=3) (20=4) (24=5)
	
	qui mlogit vote1 $rhs $y06, base(2) nolog
	
	postfile pr ccode year obs pr1 pr2 pr3 pr4 pr5 se1 se2 se3 se4 se5 using "Czech--2006.dta", replace

	keep if e(sample)
	local obs = `e(N)'
	estsimp `e(cmdline)'
	qui foreach n of numlist 1(1)`obs' {
		setx [`n']
		simqi, fd(genpr(pr1 pr2 pr3 pr4 pr5)) changex($v)
		foreach p of numlist 1(1)5 {
			qui sum pr`p'
			local pr`p' = r(mean)
			local se`p' = r(sd)
		}
		post pr (`cc') (`y') (`n') (`pr1') (`pr2') (`pr3') (`pr4') (`pr5') (`se1') (`se2') (`se3') (`se4') (`se5')
		cap drop pr*	
		if mod(`n',50) == 0 {
			nois display "." _c
			if mod(`n',1000) == 0 {
				nois display ""
			}
		}			
	}
	postclose pr
restore

preserve
	use "Czech--2006.dta", clear
	foreach v in party pr se govt pm {
		gen `v' = .
	}	
	foreach n of numlist 1(1)5 {
		qui sum pr`n'
		local mn`n' = r(mean)
		qui sum se`n'
		local se`n' = r(mean)
		di as result "Change in probability for party `n' " = `mn`n'' "  95% CI = [" `mn`n''-(1.96*`se`n'') ", " `mn`n''+(1.96*`se`n'')
		
		replace pr = `mn`n'' in `n'
		replace se = `se`n'' in `n'
	}	
	replace party = 82413 in 1
	replace party = 82320 in 2
	replace party = 82110 in 3
	replace party = 82220 in 4
	replace party = 82523 in 5
	replace pm = 1 in 1
	replace g = 1 in 1	
	
	drop pr1-se5
	gen N = _N	
	drop if _n > 5
	sort ccode year
	save "Czech--2006.dta", replace
restore

*** Italy 1990
preserve
	local cc = 325
	local y = 1990
	keep if ccode == `cc' & year == `y'

	recode vote1 (3/7 10=.) (8=3) (9=4)
	
	qui mlogit vote1 $rhs own_home redistribute_agree progressive_tax_agree, base(2) nolog
	
	postfile pr ccode year obs pr1 pr2 pr3 pr4 se1 se2 se3 se4 using "Italy--1990.dta", replace

	keep if e(sample)
	local obs = `e(N)'
	estsimp `e(cmdline)'
	qui foreach n of numlist 1(1)`obs' {
		setx [`n']
		simqi, fd(genpr(pr1 pr2 pr3 pr4)) changex($v)
		foreach p of numlist 1(1)4 {
			qui sum pr`p'
			local pr`p' = r(mean)
			local se`p' = r(sd)
		}
		post pr (`cc') (`y') (`n') (`pr1') (`pr2') (`pr3') (`pr4') (`se1') (`se2') (`se3') (`se4')
		cap drop pr1 - pr4	
		if mod(`n',50) == 0 {
			nois display "." _c
			if mod(`n',1000) == 0 {
				nois display ""
			}
		}			
	}
	postclose pr
restore

preserve
	use "Italy--1990.dta", clear
	foreach v in party pr se govt pm {
		gen `v' = .
	}	
	foreach n of numlist 1(1)4 {
		qui sum pr`n'
		local mn`n' = r(mean)
		qui sum se`n'
		local se`n' = r(mean)
		di as result "Change in probability for party `n' " = `mn`n'' "  95% CI = [" `mn`n''-(1.96*`se`n'') ", " `mn`n''+(1.96*`se`n'')
		
		replace pr = `mn`n'' in `n'
		replace se = `se`n'' in `n'
	}	
	replace party = 32520 in 1
	replace party = 32320 in 2
	replace party = 32110 in 3
	replace party = 32220 in 4
	replace pm = 1 in 1
	replace g = 1 in 1/2	
	
	drop pr1-se4
	gen N = _N	
	drop if _n > 4
	sort ccode year
	save "Italy--1990.dta", replace
restore

*** Croatia 2006
preserve
	local cc = 344
	local y = 2006
	keep if ccode == `cc' & year == `y'

	recode vote1 (5/8=.)
	
	qui mlogit vote1 spend_health_3 spend_defense_3 cut_gov_spending_3 male age income_quartile public_employee_d union religiosity $y06, base(2) nolog
	
	postfile pr ccode year obs pr1 pr2 pr3 pr4 se1 se2 se3 se4 using "Croatia--2006.dta", replace

	keep if e(sample)
	local obs = `e(N)'
	estsimp `e(cmdline)'
	qui foreach n of numlist 1(1)`obs' {
		setx [`n']
		simqi, fd(genpr(pr1 pr2 pr3 pr4)) changex($v)
		foreach p of numlist 1(1)4 {
			qui sum pr`p'
			local pr`p' = r(mean)
			local se`p' = r(sd)
		}
		post pr (`cc') (`y') (`n') (`pr1') (`pr2') (`pr3') (`pr4') (`se1') (`se2') (`se3') (`se4')
		cap drop pr*	
		if mod(`n',50) == 0 {
			nois display "." _c
			if mod(`n',1000) == 0 {
				nois display ""
			}
		}			
	}
	postclose pr
restore

preserve
	use "Croatia--2006.dta", clear
	foreach v in party pr se govt pm {
		gen `v' = .
	}	
	foreach n of numlist 1(1)4 {
		qui sum pr`n'
		local mn`n' = r(mean)
		qui sum se`n'
		local se`n' = r(mean)
		di as result "Change in probability for party `n' " = `mn`n'' "  95% CI = [" `mn`n''-(1.96*`se`n'') ", " `mn`n''+(1.96*`se`n'')
		
		replace pr = `mn`n'' in `n'
		replace se = `se`n'' in `n'
	}	
	replace party = 81711 in 1
	replace party = 81223 in 2
	replace party = 81713 in 3
	replace party = 81810 in 4
	replace pm = 1 in 1
	replace g = 1 in 1	
	
	drop pr1-se4
	gen N = _N	
	drop if _n > 4
	sort ccode year
	save "Croatia--2006.dta", replace
restore

*** Slovenia 1995
preserve
	local cc = 349
	local y = 1995
	keep if ccode == `cc' & year == `y'

	recode vote1 (6 8=.) (7=6)
	
	qui mlogit vote1 spend_health_3 spend_defense_3 create_jobs_favor cut_gov_spending_3 male age income_quartile public_employee_d union religiosity $y96, base(2) nolog
	
	postfile pr ccode year obs pr1 pr2 pr3 pr4 pr5 pr6 se1 se2 se3 se4 se5 se6 using "Slovenia--1995.dta", replace

	keep if e(sample)
	local obs = `e(N)'
	estsimp `e(cmdline)'
	qui foreach n of numlist 1(1)`obs' {
		setx [`n']
		simqi, fd(genpr(pr1 pr2 pr3 pr4 pr5 pr6)) changex($v)
		foreach p of numlist 1(1)6 {
			qui sum pr`p'
			local pr`p' = r(mean)
			local se`p' = r(sd)
		}
		post pr (`cc') (`y') (`n') (`pr1') (`pr2') (`pr3') (`pr4') (`pr5') (`pr6') (`se1') (`se2') (`se3') (`se4') (`se5') (`se6')
		cap drop pr*	
		if mod(`n',50) == 0 {
			nois display "." _c
			if mod(`n',1000) == 0 {
				nois display ""
			}
		}			
	}
	postclose pr
restore

preserve
	use "Slovenia--1995.dta", clear
	foreach v in party pr se govt pm {
		gen `v' = .
	}	
	foreach n of numlist 1(1)6 {
		qui sum pr`n'
		local mn`n' = r(mean)
		qui sum se`n'
		local se`n' = r(mean)
		di as result "Change in probability for party `n' " = `mn`n'' "  95% CI = [" `mn`n''-(1.96*`se`n'') ", " `mn`n''+(1.96*`se`n'')
		
		replace pr = `mn`n'' in `n'
		replace se = `se`n'' in `n'
	}	
	replace party = 97421 in 1
	replace party = 97520 in 2
	replace party = 97223 in 3
	replace party = 97320 in 4
	replace party = 97521 in 5 
	replace party = 97110 in 6
	replace pm = 1 in 1
	replace g = 1 in 1/3	
	
	drop pr1-se6
	gen N = _N	
	drop if _n > 6
	sort ccode year
	save "Slovenia--1995.dta", replace
restore

*** Slovenia 2006
preserve
	local cc = 349
	local y = 2006
	keep if ccode == `cc' & year == `y'

	recode vote1 (5=.) (6=5) (7=6)
	
	qui mlogit vote1 spend_health_3 spend_defense_3 create_jobs_favor cut_gov_spending_3 male age income_quartile union religiosity $y06, base(2) nolog
	
	postfile pr ccode year obs pr1 pr2 pr3 pr4 pr5 pr6 se1 se2 se3 se4 se5 se6 using "Slovenia--2006.dta", replace

	keep if e(sample)
	local obs = `e(N)'
	estsimp `e(cmdline)'
	qui foreach n of numlist 1(1)`obs' {
		setx [`n']
		simqi, fd(genpr(pr1 pr2 pr3 pr4 pr5 pr6)) changex($v)
		foreach p of numlist 1(1)6 {
			qui sum pr`p'
			local pr`p' = r(mean)
			local se`p' = r(sd)
		}
		post pr (`cc') (`y') (`n') (`pr1') (`pr2') (`pr3') (`pr4') (`pr5') (`pr6') (`se1') (`se2') (`se3') (`se4') (`se5') (`se6')
		cap drop pr*	
		if mod(`n',50) == 0 {
			nois display "." _c
			if mod(`n',1000) == 0 {
				nois display ""
			}
		}			
	}
	postclose pr
restore

preserve
	use "Slovenia--2006.dta", clear
	foreach v in party pr se govt pm {
		gen `v' = .
	}	
	foreach n of numlist 1(1)6 {
		qui sum pr`n'
		local mn`n' = r(mean)
		qui sum se`n'
		local se`n' = r(mean)
		di as result "Change in probability for party `n' " = `mn`n'' "  95% CI = [" `mn`n''-(1.96*`se`n'') ", " `mn`n''+(1.96*`se`n'')
		
		replace pr = `mn`n'' in `n'
		replace se = `se`n'' in `n'
	}	
	replace party = 97330 in 1
	replace party = 97522 in 2
	replace party = 97521 in 3
	replace party = 97951 in 4
	replace party = 97421 in 5
	replace party = 97322 in 6
	replace pm = 1 in 1
	replace g = 1 in 1/4	
	
	drop pr1-se6
	gen N = _N
	drop if _n > 6
	sort ccode year
	save "Slovenia--2006.dta", replace
restore

*** Bulgaria 1997
preserve
	local cc = 355
	local y = 1997
	keep if ccode == `cc' & year == `y'

	recode vote1 (3/5=.) (2=0)

	qui logit vote1 $rhs $y96
	
	postfile pr ccode year obs pr0 pr1 se0 se1 using "Bulgaria--1997.dta", replace

	keep if e(sample)
	local obs = `e(N)'
	estsimp `e(cmdline)'
	qui foreach n of numlist 1(1)`obs' {
		setx [`n']
		simqi, fd(prval(0 1) genpr(pr0 pr1)) changex($v)
		foreach p of numlist 0(1)1 {
			qui sum pr`p'
			local pr`p' = r(mean)
			local se`p' = r(sd)
		}
		post pr (`cc') (`y') (`n') (`pr0') (`pr1') (`se0') (`se1')
		cap drop pr*	
		if mod(`n',50) == 0 {
			nois display "." _c
			if mod(`n',1000) == 0 {
				nois display ""
			}
		}			
	}
	postclose pr
restore

preserve
	use "Bulgaria--1997.dta", clear
	foreach v in party pr se govt pm {
		gen `v' = .
	}	
	foreach n of numlist 0(1)1 {
		qui sum pr`n'
		local mn`n' = r(mean)
		qui sum se`n'
		local se`n' = r(mean)
		di as result "Change in probability for party `n' " = `mn`n'' "  95% CI = [" `mn`n''-(1.96*`se`n'') ", " `mn`n''+(1.96*`se`n'')
		local b = `n' + 1
		replace pr = `mn`n'' in `b'
		replace se = `se`n'' in `b'
	}	
	replace party = 80410 in 1
	replace party = 80220 in 2
	replace pm = 1 in 2
	replace g = 1 in 2	
	
	drop pr0-se1
	gen N = _N	
	drop if _n > 2
	sort ccode year
	save "Bulgaria--1997.dta", replace
restore

*** Latvia 2007
preserve
	local cc = 367
	local y = 2007
	keep if ccode == `cc' & year == `y'

	recode vote1 (3/5=.) (15=3)
	
	qui mlogit vote1 spend_health_3 spend_defense_3 create_jobs_favor cut_gov_spending_3 male age income_quartile public_employee_d union religiosity $y06, base(2) nolog
	
	postfile pr ccode year obs pr1 pr2 pr3 se1 se2 se3 using "Latvia--2007.dta", replace

	keep if e(sample)
	local obs = `e(N)'
	estsimp `e(cmdline)'
	qui foreach n of numlist 1(1)`obs' {
		setx [`n']
		simqi, fd(genpr(pr1 pr2 pr3)) changex($v)
		foreach p of numlist 1(1)3 {
			qui sum pr`p'
			local pr`p' = r(mean)
			local se`p' = r(sd)
		}
		post pr (`cc') (`y') (`n') (`pr1') (`pr2') (`pr3') (`se1') (`se2') (`se3')
		cap drop pr*	
		if mod(`n',50) == 0 {
			nois display "." _c
			if mod(`n',1000) == 0 {
				nois display ""
			}
		}			
	}
	postclose pr
restore

preserve
	use "Latvia--2007.dta", clear
	foreach v in party pr se govt pm {
		gen `v' = .
	}	
	foreach n of numlist 1(1)3 {
		qui sum pr`n'
		local mn`n' = r(mean)
		qui sum se`n'
		local se`n' = r(mean)
		di as result "Change in probability for party `n' " = `mn`n'' "  95% CI = [" `mn`n''-(1.96*`se`n'') ", " `mn`n''+(1.96*`se`n'')
		
		replace pr = `mn`n'' in `n'
		replace se = `se`n'' in `n'
	}	
	replace party = 87610 in 1
	replace party = 87110 in 2
	replace party = 87423 in 3
	replace pm = 1 in 1
	replace g = 1 in 1/2	
	
	drop pr1-se3
	gen N = _N	
	drop if _n > 3
	sort ccode year
	save "Latvia--2007.dta", replace
restore

*** Finland 2006
preserve
	local cc = 375
	local y = 2006
	keep if ccode == `cc' & year == `y'

	recode vote1 (7/8=.)
	
	qui mlogit vote1 $rhs, base(2) nolog
	
	postfile pr ccode year obs pr1 pr2 pr3 pr4 pr5 pr6 se1 se2 se3 se4 se5 se6 using "Finland--2006.dta", replace

	keep if e(sample)
	local obs = `e(N)'
	estsimp `e(cmdline)'
	qui foreach n of numlist 1(1)`obs' {
		setx [`n']
		simqi, fd(genpr(pr1 pr2 pr3 pr4 pr5 pr6)) changex($v)
		foreach p of numlist 1(1)6 {
			qui sum pr`p'
			local pr`p' = r(mean)
			local se`p' = r(sd)
		}
		post pr (`cc') (`y') (`n') (`pr1') (`pr2') (`pr3') (`pr4') (`pr5') (`pr6') (`se1') (`se2') (`se3') (`se4') (`se5') (`se6')
		cap drop pr*	
		if mod(`n',50) == 0 {
			nois display "." _c
			if mod(`n',1000) == 0 {
				nois display ""
			}
		}			
	}
	postclose pr
restore

preserve
	use "Finland--2006.dta", clear
	foreach v in party pr se govt pm {
		gen `v' = .
	}	
	foreach n of numlist 1(1)6 {
		qui sum pr`n'
		local mn`n' = r(mean)
		qui sum se`n'
		local se`n' = r(mean)
		di as result "Change in probability for party `n' " = `mn`n'' "  95% CI = [" `mn`n''-(1.96*`se`n'') ", " `mn`n''+(1.96*`se`n'')
		
		replace pr = `mn`n'' in `n'
		replace se = `se`n'' in `n'
	}	
	replace party = 14810 in 1
	replace party = 14320 in 2
	replace party = 14901 in 3
	replace party = 14223 in 4
	replace party = 14620 in 5
	replace party = 14110 in 6
	replace pm = 1 in 1
	replace g = 1 in 1/3	
	
	drop pr1-se6
	gen N = _N	
	drop if _n > 6
	sort ccode year
	save "Finland--2006.dta", replace
restore

*** Sweden 1996
preserve
	local cc = 380
	local y = 1996
	keep if ccode == `cc' & year == `y'

	recode vote1 (3=.) (4=3) (5=4) (6=5)
	
	qui mlogit vote1 $rhs $y96, base(2) nolog
	
	postfile pr ccode year obs pr1 pr2 pr3 pr4 pr5 se1 se2 se3 se4 se5 using "Sweden--1996.dta", replace

	keep if e(sample)
	local obs = `e(N)'
	estsimp `e(cmdline)'
	qui foreach n of numlist 1(1)`obs' {
		setx [`n']
		simqi, fd(genpr(pr1 pr2 pr3 pr4 pr5)) changex($v)
		foreach p of numlist 1(1)5 {
			qui sum pr`p'
			local pr`p' = r(mean)
			local se`p' = r(sd)
		}
		post pr (`cc') (`y') (`n') (`pr1') (`pr2') (`pr3') (`pr4') (`pr5') (`se1') (`se2') (`se3') (`se4') (`se5')
		cap drop pr*	
		if mod(`n',50) == 0 {
			nois display "." _c
			if mod(`n',1000) == 0 {
				nois display ""
			}
		}			
	}
	postclose pr
restore

preserve
	use "Sweden--1996.dta", clear
	foreach v in party pr se govt pm {
		gen `v' = .
	}	
	foreach n of numlist 1(1)5 {
		qui sum pr`n'
		local mn`n' = r(mean)
		qui sum se`n'
		local se`n' = r(mean)
		di as result "Change in probability for party `n' " = `mn`n'' "  95% CI = [" `mn`n''-(1.96*`se`n'') ", " `mn`n''+(1.96*`se`n'')
		
		replace pr = `mn`n'' in `n'
		replace se = `se`n'' in `n'
	}	
	replace party = 11320 in 1
	replace party = 11420 in 2
	replace party = 11110 in 3
	replace party = 11620 in 4
	replace party = 11810 in 5
	replace pm = 1 in 1
	replace g = 1 in 1	
	
	drop pr1-se5
	gen N = _N	
	drop if _n > 5
	sort ccode year
	save "Sweden--1996.dta", replace
restore

*** Sweden 2006
preserve
	local cc = 380
	local y = 2006
	keep if ccode == `cc' & year == `y'
	
	qui mlogit vote1 $rhs $y06, base(2) nolog
	
	postfile pr ccode year obs pr1 pr2 pr3 pr4 pr5 pr6 pr7 se1 se2 se3 se4 se5 se6 se7 using "Sweden--2006.dta", replace

	keep if e(sample)
	local obs = `e(N)'
	estsimp `e(cmdline)'
	qui foreach n of numlist 1(1)`obs' {
		setx [`n']
		simqi, fd(genpr(pr1 pr2 pr3 pr4 pr5 pr6 pr7)) changex($v)
		foreach p of numlist 1(1)7 {
			qui sum pr`p'
			local pr`p' = r(mean)
			local se`p' = r(sd)
		}
		post pr (`cc') (`y') (`n') (`pr1') (`pr2') (`pr3') (`pr4') (`pr5') (`pr6') (`pr7') (`se1') (`se2') (`se3') (`se4') (`se5') (`se6') (`se7')
		cap drop pr*	
		if mod(`n',50) == 0 {
			nois display "." _c
			if mod(`n',1000) == 0 {
				nois display ""
			}
		}			
	}
	postclose pr
restore

preserve
	use "Sweden--2006.dta", clear
	foreach v in party pr se govt pm {
		gen `v' = .
	}	
	foreach n of numlist 1(1)7 {
		qui sum pr`n'
		local mn`n' = r(mean)
		qui sum se`n'
		local se`n' = r(mean)
		di as result "Change in probability for party `n' " = `mn`n'' "  95% CI = [" `mn`n''-(1.96*`se`n'') ", " `mn`n''+(1.96*`se`n'')
		
		replace pr = `mn`n'' in `n'
		replace se = `se`n'' in `n'
	}	
	replace party = 11320 in 1
	replace party = 11420 in 2
	replace party = 11520 in 3
	replace party = 11110 in 4
	replace party = 11620 in 5
	replace party = 11810 in 6
	replace party = 11220 in 7
	replace pm = 1 in 1
	replace g = 1 in 1	
	
	drop pr1-se7
	gen N = _N	
	drop if _n > 7
	sort ccode year
	save "Sweden--2006.dta", replace
restore

*** Norway 1990
preserve
	local cc = 385
	local y = 1990
	keep if ccode == `cc' & year == `y'

	recode vote1 (7=.)
	
	qui mlogit vote1 $rhs lower_class redistribute_agree progressive_tax_agree, base(2) nolog
	
	postfile pr ccode year obs pr1 pr2 pr3 pr4 pr5 pr6 se1 se2 se3 se4 se5 se6 using "Norway--1990.dta", replace

	keep if e(sample)
	local obs = `e(N)'
	estsimp `e(cmdline)'
	qui foreach n of numlist 1(1)`obs' {
		setx [`n']
		simqi, fd(genpr(pr1 pr2 pr3 pr4 pr5 pr6)) changex($v)
		foreach p of numlist 1(1)6 {
			qui sum pr`p'
			local pr`p' = r(mean)
			local se`p' = r(sd)
		}
		post pr (`cc') (`y') (`n') (`pr1') (`pr2') (`pr3') (`pr4') (`pr5') (`pr6') (`se1') (`se2') (`se3') (`se4') (`se5') (`se6')
		cap drop pr1 - pr6	
		if mod(`n',50) == 0 {
			nois display "." _c
			if mod(`n',1000) == 0 {
				nois display ""
			}
		}			
	}
	postclose pr
restore

preserve
	use "Norway--1990.dta", clear
	foreach v in party pr se govt pm {
		gen `v' = .
	}	
	foreach n of numlist 1(1)6 {
		qui sum pr`n'
		local mn`n' = r(mean)
		qui sum se`n'
		local se`n' = r(mean)
		di as result "Change in probability for party `n' " = `mn`n'' "  95% CI = [" `mn`n''-(1.96*`se`n'') ", " `mn`n''+(1.96*`se`n'')
		
		replace pr = `mn`n'' in `n'
		replace se = `se`n'' in `n'
	}	
	replace party = 12620 in 1
	replace party = 12520 in 2
	replace party = 12810 in 3
	replace party = 12320 in 4
	replace party = 12951 in 5
	replace party = 12221 in 6
	replace pm = 1 in 1
	replace g = 1 in 1/3	
	
	drop pr1-se6
	gen N = _N	
	drop if _n > 6
	sort ccode year
	save "Norway--1990.dta", replace
restore

*** Norway 1996
preserve
	local cc = 385
	local y = 1996
	keep if ccode == `cc' & year == `y'

	recode vote1 (3=2) (4=3) (5=4) (6=5) (7=6) (8=.)
	
	qui mlogit vote1 $rhs $y96, base(2) nolog
	
	postfile pr ccode year obs pr1 pr2 pr3 pr4 pr5 pr6 se1 se2 se3 se4 se5 se6 using "Norway--1996.dta", replace

	keep if e(sample)
	local obs = `e(N)'
	estsimp `e(cmdline)'
	qui foreach n of numlist 1(1)`obs' {
		setx [`n']
		simqi, fd(genpr(pr1 pr2 pr3 pr4 pr5 pr6)) changex($v)
		foreach p of numlist 1(1)6 {
			qui sum pr`p'
			local pr`p' = r(mean)
			local se`p' = r(sd)
		}
		post pr (`cc') (`y') (`n') (`pr1') (`pr2') (`pr3') (`pr4') (`pr5') (`pr6') (`se1') (`se2') (`se3') (`se4') (`se5') (`se6')
		cap drop pr*	
		if mod(`n',50) == 0 {
			nois display "." _c
			if mod(`n',1000) == 0 {
				nois display ""
			}
		}			
	}
	postclose pr
restore

preserve
	use "Norway--1996.dta", clear
	foreach v in party pr se govt pm {
		gen `v' = .
	}	
	foreach n of numlist 1(1)6 {
		qui sum pr`n'
		local mn`n' = r(mean)
		qui sum se`n'
		local se`n' = r(mean)
		di as result "Change in probability for party `n' " = `mn`n'' "  95% CI = [" `mn`n''-(1.96*`se`n'') ", " `mn`n''+(1.96*`se`n'')
		
		replace pr = `mn`n'' in `n'
		replace se = `se`n'' in `n'
	}	
	replace party = 12320 in 1
	replace party = 12951 in 2
	replace party = 12620 in 3
	replace party = 12520 in 4
	replace party = 12810 in 5
	replace party = 12221 in 6
	replace pm = 1 in 1
	replace g = 1 in 1	
	
	drop pr1-se6
	gen N = _N	
	drop if _n > 6
	sort ccode year
	save "Norway--1996.dta", replace
restore

*** Norway 2006
preserve
	local cc = 385
	local y = 2006
	keep if ccode == `cc' & year == `y'

	recode vote1 (8=7)
	
	qui mlogit vote1 $rhs, base(2) nolog
	
	postfile pr ccode year obs pr1 pr2 pr3 pr4 pr5 pr6 pr7 se1 se2 se3 se4 se5 se6 se7 using "Norway--2006.dta", replace

	keep if e(sample)
	local obs = `e(N)'
	estsimp `e(cmdline)'
	qui foreach n of numlist 1(1)`obs' {
		setx [`n']
		simqi, fd(genpr(pr1 pr2 pr3 pr4 pr5 pr6 pr7)) changex($v)
		foreach p of numlist 1(1)7 {
			qui sum pr`p'
			local pr`p' = r(mean)
			local se`p' = r(sd)
		}
		post pr (`cc') (`y') (`n') (`pr1') (`pr2') (`pr3') (`pr4') (`pr5') (`pr6') (`pr7') (`se1') (`se2') (`se3') (`se4') (`se5') (`se6') (`se7')
		cap drop pr*	
		if mod(`n',50) == 0 {
			nois display "." _c
			if mod(`n',1000) == 0 {
				nois display ""
			}
		}			
	}
	postclose pr
restore

preserve
	use "Norway--2006.dta", clear
	foreach v in party pr se govt pm {
		gen `v' = .
	}	
	foreach n of numlist 1(1)7 {
		qui sum pr`n'
		local mn`n' = r(mean)
		qui sum se`n'
		local se`n' = r(mean)
		di as result "Change in probability for party `n' " = `mn`n'' "  95% CI = [" `mn`n''-(1.96*`se`n'') ", " `mn`n''+(1.96*`se`n'')
		
		replace pr = `mn`n'' in `n'
		replace se = `se`n'' in `n'
	}	
	replace party = 12320 in 1
	replace party = 12221 in 2
	replace party = 12810 in 3
	replace party = 12620 in 4
	replace party = 12520 in 5
	replace party = 12951 in 6
	replace party = 12420 in 7
	replace pm = 1 in 1
	replace g = 1 in 1	
	
	drop pr1-se7
	gen N = _N	
	drop if _n > 7
	sort ccode year
	save "Norway--2006.dta", replace
restore

*** Denmark 2008
preserve
	local cc = 390
	local y = 2008
	keep if ccode == `cc' & year == `y'

	recode vote1 (6=5) (7=6) (8=7) (9=.)
	
	qui mlogit vote1 $rhs $y06, base(2) nolog
	
	postfile pr ccode year obs pr1 pr2 pr3 pr4 pr5 pr6 pr7 se1 se2 se3 se4 se5 se6 se7 using "Denmark--2008.dta", replace

	keep if e(sample)
	local obs = `e(N)'
	estsimp `e(cmdline)'
	qui foreach n of numlist 1(1)`obs' {
		setx [`n']
		simqi, fd(genpr(pr1 pr2 pr3 pr4 pr5 pr6 pr7)) changex($v)
		foreach p of numlist 1(1)7 {
			qui sum pr`p'
			local pr`p' = r(mean)
			local se`p' = r(sd)
		}
		post pr (`cc') (`y') (`n') (`pr1') (`pr2') (`pr3') (`pr4') (`pr5') (`pr6') (`pr7') (`se1') (`se2') (`se3') (`se4') (`se5') (`se6') (`se7')
		cap drop pr*	
		if mod(`n',50) == 0 {
			nois display "." _c
			if mod(`n',1000) == 0 {
				nois display ""
			}
		}			
	}
	postclose pr
restore

preserve
	use "Denmark--2008.dta", clear
	foreach v in party pr se govt pm {
		gen `v' = .
	}	
	foreach n of numlist 1(1)7 {
		qui sum pr`n'
		local mn`n' = r(mean)
		qui sum se`n'
		local se`n' = r(mean)
		di as result "Change in probability for party `n' " = `mn`n'' "  95% CI = [" `mn`n''-(1.96*`se`n'') ", " `mn`n''+(1.96*`se`n'')
		
		replace pr = `mn`n'' in `n'
		replace se = `se`n'' in `n'
	}	
	replace party = 13420 in 1
	replace party = 13620 in 2
	replace party = 13410 in 3
	replace party = 13230 in 4
	replace party = 13720 in 5
	replace party = 13320 in 6
	replace party = 13001 in 7
	replace pm = 1 in 1
	replace g = 1 in 1/2	
	
	drop pr1-se7
	gen N = _N	
	drop if _n > 7
	sort ccode year
	save "Denmark--2008.dta", replace
restore

*** Japan 1996
preserve
	local cc = 740
	local y = 1996
	keep if ccode == `cc' & year == `y'
	
	recode vote1 (3=.) (4=3) (5=4)
	
	qui mlogit vote1 $rhs $y96, base(2) nolog
	
	postfile pr ccode year obs pr1 pr2 pr3 pr4 se1 se2 se3 se4 using "Japan--1996.dta", replace

	keep if e(sample)
	local obs = `e(N)'
	estsimp `e(cmdline)'
	qui foreach n of numlist 1(1)`obs' {
		setx [`n']
		simqi, fd(genpr(pr1 pr2 pr3 pr4)) changex($v)
		foreach p of numlist 1(1)4 {
			qui sum pr`p'
			local pr`p' = r(mean)
			local se`p' = r(sd)
		}
		post pr (`cc') (`y') (`n') (`pr1') (`pr2') (`pr3') (`pr4') (`se1') (`se2') (`se3') (`se4')
		cap drop pr*	
		if mod(`n',50) == 0 {
			nois display "." _c
			if mod(`n',1000) == 0 {
				nois display ""
			}
		}			
	}
	postclose pr
restore

preserve
	use "Japan--1996.dta", clear
	foreach v in party pr se govt pm {
		gen `v' = .
	}	
	foreach n of numlist 1(1)4 {
		qui sum pr`n'
		local mn`n' = r(mean)
		qui sum se`n'
		local se`n' = r(mean)
		di as result "Change in probability for party `n' " = `mn`n'' "  95% CI = [" `mn`n''-(1.96*`se`n'') ", " `mn`n''+(1.96*`se`n'')
		
		replace pr = `mn`n'' in `n'
		replace se = `se`n'' in `n'
	}	
	replace party = 71620 in 1
	replace party = 71320 in 2
	replace party = 71623 in 3
	replace party = 71220 in 4
	replace pm = 1 in 1
	replace g = 1 in 1/2	
	
	drop pr1-se4
	gen N = _N	
	drop if _n > 4
	sort ccode year
	save "Japan--1996.dta", replace
restore

*** Japan 2006
preserve
	local cc = 740
	local y = 2006
	keep if ccode == `cc' & year == `y'

	recode vote1 (5/6=.) (4=3)
	
	qui mlogit vote1 spend_health_3 spend_defense_3 create_jobs_favor cut_gov_spending_3 male age income_quartile union educ religiosity $y06, base(2) nolog
	
	postfile pr ccode year obs pr1 pr2 pr3 se1 se2 se3 using "Japan--2006.dta", replace

	keep if e(sample)
	local obs = `e(N)'
	estsimp `e(cmdline)'
	qui foreach n of numlist 1(1)`obs' {
		setx [`n']
		simqi, fd(genpr(pr1 pr2 pr3)) changex($v)
		foreach p of numlist 1(1)3 {
			qui sum pr`p'
			local pr`p' = r(mean)
			local se`p' = r(sd)
		}
		post pr (`cc') (`y') (`n') (`pr1') (`pr2') (`pr3') (`se1') (`se2') (`se3')
		cap drop pr*	
		if mod(`n',50) == 0 {
			nois display "." _c
			if mod(`n',1000) == 0 {
				nois display ""
			}
		}			
	}
	postclose pr
restore

preserve
	use "Japan--2006.dta", clear
	foreach v in party pr se govt pm {
		gen `v' = .
	}	
	foreach n of numlist 1(1)3 {
		qui sum pr`n'
		local mn`n' = r(mean)
		qui sum se`n'
		local se`n' = r(mean)
		di as result "Change in probability for party `n' " = `mn`n'' "  95% CI = [" `mn`n''-(1.96*`se`n'') ", " `mn`n''+(1.96*`se`n'')
		
		replace pr = `mn`n'' in `n'
		replace se = `se`n'' in `n'
	}	
	replace party = 71620 in 1
	replace party = 71530 in 2
	replace party = 71624 in 3
	replace pm = 1 in 1
	replace g = 1 in 1/2	
	
	drop pr1-se3
	gen N = _N	
	drop if _n > 3
	sort ccode year
	save "Japan--2006.dta", replace
restore

*** Australia 1986
preserve
	local cc = 900
	local y = 1986
	keep if ccode == `cc' & year == `y'

	qui mlogit vote1 $rhs $y86, base(2) nolog
	
	postfile pr ccode year obs pr1 pr2 pr3 se1 se2 se3 using "Australia--1986.dta", replace

	keep if e(sample)
	local obs = `e(N)'
	estsimp `e(cmdline)'
	qui foreach n of numlist 1(1)`obs' {
		setx [`n']
		simqi, fd(genpr(pr1 pr2 pr3)) changex($v)
		foreach p of numlist 1(1)3 {
			qui sum pr`p'
			local pr`p' = r(mean)
			local se`p' = r(sd)
		}
		post pr (`cc') (`y') (`n') (`pr1') (`pr2') (`pr3') (`se1') (`se2') (`se3')
		cap drop pr1 - pr3	
		if mod(`n',50) == 0 {
			nois display "." _c
			if mod(`n',1000) == 0 {
				nois display ""
			}
		}			
	}
	postclose pr
restore

preserve
	use "Australia--1986.dta", clear
	foreach v in party pr se govt pm {
		gen `v' = .
	}	
	foreach n of numlist 1(1)3 {
		qui sum pr`n'
		local mn`n' = r(mean)
		qui sum se`n'
		local se`n' = r(mean)
		di as result "Change in probability for party `n' " = `mn`n'' "  95% CI = [" `mn`n''-(1.96*`se`n'') ", " `mn`n''+(1.96*`se`n'')
		
		replace pr = `mn`n'' in `n'
		replace se = `se`n'' in `n'
	}	
	replace party = 63320 in 1
	replace party = 63620 in 2
	replace party = 63810 in 3
	replace pm = 1 in 1
	replace g = 1 in 1	
	
	drop pr1-se3
	gen N = _N	
	drop if _n > 3
	sort ccode year
	save "Australia--1986.dta", replace
restore

*** Australia 1990
preserve
	local cc = 900
	local y = 1990
	keep if ccode == `cc' & year == `y'

	qui mlogit vote1 $rhs $y90, base(2) nolog
	
	postfile pr ccode year obs pr1 pr2 pr3 pr4 se1 se2 se3 se4 using "Australia--1990.dta", replace

	keep if e(sample)
	local obs = `e(N)'
	estsimp `e(cmdline)'
	local n = 1
	qui while `n' <= `obs' {
		setx [`n']
		simqi, fd(genpr(pr1 pr2 pr3 pr4)) changex($v)
		foreach p of numlist 1(1)4 {
			qui sum pr`p'
			local pr`p' = r(mean)
			local se`p' = r(sd)
		}
		post pr (`cc') (`y') (`n') (`pr1') (`pr2') (`pr3') (`pr4') (`se1') (`se2') (`se3') (`se4')
		cap drop pr1 - pr4	
		if mod(`n',50) == 0 {
			nois display "." _c
			if mod(`n',1000) == 0 {
				nois display ""
			}
		}
		local n = `n' + 1
	}
	postclose pr
restore

preserve
	use "Australia--1990.dta", clear
	foreach v in party pr se govt pm {
		gen `v' = .
	}	
	foreach n of numlist 1(1)4 {
		qui sum pr`n'
		local mn`n' = r(mean)
		qui sum se`n'
		local se`n' = r(mean)
		di as result "Change in probability for party `n' " = `mn`n'' "  95% CI = [" `mn`n''-(1.96*`se`n'') ", " `mn`n''+(1.96*`se`n'')
		
		replace pr = `mn`n'' in `n'
		replace se = `se`n'' in `n'
	}	
	replace party = 63320 in 1
	replace party = 63620 in 2
	replace party = 63810 in 3
	replace party = 63321 in 4
	replace pm = 1 in 1
	replace g = 1 in 1	
	
	drop pr1-se4
	gen N = _N	
	drop if _n > 4
	sort ccode year
	save "Australia--1990.dta", replace
restore

*** Australia 1996
preserve
	local cc = 900
	local y = 1996
	keep if ccode == `cc' & year == `y'

	qui mlogit vote1 spend_health_3 spend_defense_3 create_jobs_favor cut_gov_spending_3 male age income_quartile public_employee_d educ religiosity $y96, base(2) nolog
	
	postfile pr ccode year obs pr1 pr2 pr3 pr4 se1 se2 se3 se4 using "Australia--1996.dta", replace

	keep if e(sample)
	local obs = `e(N)'
	estsimp `e(cmdline)'
	local n = 1
	qui while `n' <= `obs' {
		setx [`n']
		simqi, fd(genpr(pr1 pr2 pr3 pr4)) changex($v)
		foreach p of numlist 1(1)4 {
			qui sum pr`p'
			local pr`p' = r(mean)
			local se`p' = r(sd)
		}
		post pr (`cc') (`y') (`n') (`pr1') (`pr2') (`pr3') (`pr4') (`se1') (`se2') (`se3') (`se4')
		cap drop pr*	
		if mod(`n',50) == 0 {
			nois display "." _c
			if mod(`n',1000) == 0 {
				nois display ""
			}
		}
		local n = `n' + 1
	}
	postclose pr
restore

preserve
	use "Australia--1996.dta", clear
	foreach v in party pr se govt pm {
		gen `v' = .
	}	
	foreach n of numlist 1(1)4 {
		qui sum pr`n'
		local mn`n' = r(mean)
		qui sum se`n'
		local se`n' = r(mean)
		di as result "Change in probability for party `n' " = `mn`n'' "  95% CI = [" `mn`n''-(1.96*`se`n'') ", " `mn`n''+(1.96*`se`n'')
		
		replace pr = `mn`n'' in `n'
		replace se = `se`n'' in `n'
	}	
	replace party = 63620 in 1
	replace party = 63810 in 2
	replace party = 63320 in 3
	replace party = 63321 in 4
	replace pm = 1 in 1
	replace g = 1 in 1/2	
	
	drop pr1-se4
	gen N = _N	
	drop if _n > 4
	sort ccode year
	save "Australia--1996.dta", replace
restore

*** Australia 2007
preserve
	local cc = 900
	local y = 2007
	keep if ccode == `cc' & year == `y'
	
	recode vote1 (5=4)

	qui mlogit vote1 $rhs $y06, base(2) nolog
	
	postfile pr ccode year obs pr1 pr2 pr3 pr4 se1 se2 se3 se4 using "Australia--2007.dta", replace

	keep if e(sample)
	local obs = `e(N)'
	estsimp `e(cmdline)'
	local n = 1
	qui while `n' <= `obs' {
		setx [`n']
		simqi, fd(genpr(pr1 pr2 pr3 pr4)) changex($v)
		foreach p of numlist 1(1)4 {
			qui sum pr`p'
			local pr`p' = r(mean)
			local se`p' = r(sd)
		}
		post pr (`cc') (`y') (`n') (`pr1') (`pr2') (`pr3') (`pr4') (`se1') (`se2') (`se3') (`se4')
		cap drop pr*	
		if mod(`n',50) == 0 {
			nois display "." _c
			if mod(`n',1000) == 0 {
				nois display ""
			}
		}
		local n = `n' + 1
	}
	postclose pr
restore

preserve
	use "Australia--2007.dta", clear
	foreach v in party pr se govt pm {
		gen `v' = .
	}	
	foreach n of numlist 1(1)4 {
		qui sum pr`n'
		local mn`n' = r(mean)
		qui sum se`n'
		local se`n' = r(mean)
		di as result "Change in probability for party `n' " = `mn`n'' "  95% CI = [" `mn`n''-(1.96*`se`n'') ", " `mn`n''+(1.96*`se`n'')
		
		replace pr = `mn`n'' in `n'
		replace se = `se`n'' in `n'
	}	
	replace party = 63620 in 1
	replace party = 63810 in 2
	replace party = 63320 in 3
	replace party = 63110 in 4
	replace pm = 1 in 1
	replace g = 1 in 1/2	
	
	drop pr1-se4
	gen N = _N
	drop if _n > 4
	sort ccode year
	save "Australia--2007.dta", replace
restore

*** New Zealand 1997
preserve
	local cc = 920
	local y = 1997
	keep if ccode == `cc' & year == `y'
	
	qui mlogit vote1 $rhs $y96, base(2) nolog
	
	postfile pr ccode year obs pr1 pr2 pr3 pr4 se1 se2 se3 se4 using "NZ--1997.dta", replace

	keep if e(sample)
	local obs = `e(N)'
	estsimp `e(cmdline)'
	local n = 1
	qui while `n' <= `obs' {
		setx [`n']
		simqi, fd(genpr(pr1 pr2 pr3 pr4)) changex($v)
		foreach p of numlist 1(1)4 {
			qui sum pr`p'
			local pr`p' = r(mean)
			local se`p' = r(sd)
		}
		post pr (`cc') (`y') (`n') (`pr1') (`pr2') (`pr3') (`pr4') (`se1') (`se2') (`se3') (`se4')
		cap drop pr*	
		if mod(`n',50) == 0 {
			nois display "." _c
			if mod(`n',1000) == 0 {
				nois display ""
			}
		}
		local n = `n' + 1
	}
	postclose pr
restore

preserve
	use "NZ--1997.dta", clear
	foreach v in party pr se govt pm {
		gen `v' = .
	}	
	foreach n of numlist 1(1)4 {
		qui sum pr`n'
		local mn`n' = r(mean)
		qui sum se`n'
		local se`n' = r(mean)
		di as result "Change in probability for party `n' " = `mn`n'' "  95% CI = [" `mn`n''-(1.96*`se`n'') ", " `mn`n''+(1.96*`se`n'')
		
		replace pr = `mn`n'' in `n'
		replace se = `se`n'' in `n'
	}	
	replace party = 64620 in 1
	replace party = 64621 in 2
	replace party = 64321 in 3
	replace party = 64320 in 4
	replace pm = 1 in 1
	replace g = 1 in 1/2	
	
	drop pr1-se4
	gen N = _N	
	drop if _n > 4
	sort ccode year
	save "NZ--1997.dta", replace
restore

*** New Zealand 2006
preserve
	local cc = 920
	local y = 2006
	keep if ccode == `cc' & year == `y'
	
	recode vote1 (2 5 9=.) (6=2)

	qui mlogit vote1 $rhs $y06, base(2) nolog
	
	postfile pr ccode year obs pr1 pr2 pr3 pr4 se1 se2 se3 se4 using "NZ--2006.dta", replace

	keep if e(sample)
	local obs = `e(N)'
	estsimp `e(cmdline)'
	local n = 1
	qui while `n' <= `obs' {
		setx [`n']
		simqi, fd(genpr(pr1 pr2 pr3 pr4)) changex($v)
		foreach p of numlist 1(1)4 {
			qui sum pr`p'
			local pr`p' = r(mean)
			local se`p' = r(sd)
		}
		post pr (`cc') (`y') (`n') (`pr1') (`pr2') (`pr3') (`pr4') (`se1') (`se2') (`se3') (`se4')
		cap drop pr*	
		if mod(`n',50) == 0 {
			nois display "." _c
			if mod(`n',1000) == 0 {
				nois display ""
			}
		}
		local n = `n' + 1
	}
	postclose pr
restore

preserve
	use "NZ--2006.dta", clear
	foreach v in party pr se govt pm {
		gen `v' = .
	}
	foreach n of numlist 1(1)4 {
		qui sum pr`n'
		local mn`n' = r(mean)
		qui sum se`n'
		local se`n' = r(mean)
		di as result "Change in probability for party `n' " = `mn`n'' "  95% CI = [" `mn`n''-(1.96*`se`n'') ", " `mn`n''+(1.96*`se`n'')
		
		replace pr = `mn`n'' in `n'
		replace se = `se`n'' in `n'
	}	
	replace party = 64320 in 1
	replace party = 64951 in 2
	replace party = 64110 in 3
	replace party = 64420 in 4
	replace pm = 1 in 1
	replace g = 1 in 1	
	
	drop pr1-se4
	gen N = _N	
	drop if _n > 4
	sort ccode year
	save "NZ--2006.dta", replace
restore

cap log close

****************************************************************
*** Create temporary files containing election and CMP data.
****************************************************************
use "ISSP--Defense Spending.dta", clear

foreach v of varlist _all {
	local l`v': var label `v'	
}

collapse (max) year next_ts fw_start fw_end govtseq (mean)  et_rile -  et_hawk_dm milex milex_tm1 milex_tm2 ch_milex_tm1 ch_milex_tm2 milex_gdp milex_gdp_tm1 milex_gdp_tm2 mid_count_all mid_count_all_6 mid_count_all_12 mid_count_all_18 mid_count_all_24 mid_count_all_36 mid_count_all_init mid_count_all_init_6 mid_count_all_init_12 mid_count_all_init_18 mid_count_all_init_24 mid_count_all_init_36 mid_count_all_targ mid_count_all_targ_18 mid_count_all_targ_24 mid_count_all_targ_36 mid_count_all_targ_12 mid_count_all_targ_6 mid_count_h mid_count_h_6 mid_count_h_12 mid_count_h_18 mid_count_h_24 mid_count_h_36 mid_onset_all mid_onset_all_6 mid_onset_all_12 mid_onset_all_18 mid_onset_all_24 mid_onset_all_36 mid_onset_f mid_onset_f_6 mid_onset_f_12 mid_onset_f_18 mid_onset_f_24 mid_onset_f_36 mid_onset_h mid_onset_h_6 mid_onset_h_12 mid_onset_h_18 mid_onset_h_24 mid_onset_h_36 annual_ch_rgdppc -  d_yune_tm1 , by(ccode last_ts)

foreach v of varlist _all {
	label var `v' "`l`v''"
}

sort ccode year
tempfile e
save `e', replace

preserve
	clear
	insheet using "CMP--Full.csv", comma 

	order countryname edate party rile
	gen last_ts = date(edate,"MDY")

	recode date (200994 = 200904)

	gen ccode = country 
	recode ccode (11 = 380) (12 = 385) (13 = 390) (14 = 375) (15 = 395) (21 = 211) (22 = 210) (23 = 212) (31 = 220) (32 = 325) (33 = 230) (34 = 350) (35 = 235) (41 = 255) (42 = 305) (43 = 225) (51 = 200) (53 = 205) (54 = 338) (55 = 352) (61 = 2) (62 = 20) (63 = 900) (64 = 920) (71 = 740) (72 = 666) (73 = 780) (74 = 640) (75 = 339) (76 = 371) (77 = 373) (78 = 370) (79 = 346) (80 = 355) (81 = 344) (82 = 316) (83 = 366) (84 = 372) (85 = 265) (86 = 310) (87 = 367) (88 = 368) (89 = 343) (90 = 359) (91 = 341) (92 = 290) (93 = 360) (94 = 365) (96 = 317) (97 = 349) (98 = 369) (113 = 730) (171 = 70)

	tempvar d
	gen `d' = party - (country*1000)
	tab ccode if `d' < 0
	gen niche = 0
	replace niche = 1 if inrange(`d', 100, 299)
	replace niche = 1 if inrange(`d', 700, 799)

	gen family = `d'
	recode family (100/199 = 10) (200/299=20) (300/399=30) (400/499=40) (500/599=50) (600/699=60) (700/799=70) (800/900=80) (901/949=90) (950/989=95) (990/999=99)
	lab def family 10 "Ecology" 20 "(Former) Communist" 30 "Social Democratic" 40 "Liberal" 50 "Christian Democrat" 60 "Conservative" 70 "National" 80 "Agrarian" 90 "Special Interest" 95 "Ethnic/Regional" 99 "Electoral Alliances"
	lab val family family

	gen left = 0
	replace left = 1 if inrange(`d', 100, 399)
	gen right = 0
	replace right = 1 if inrange(`d', 500, 799)
	gen center = 0
	replace center = 1 if (left == 0 & right == 0)

	gen milspend = per104 - per105
	gen international = per107 - per109
	gen hawk = per104 - per105 - per106
	gen epp = (per401 + per402 + per407 + per414) - (per403 + per404 + per405 + per406 + per412)

	lab var rile "Right/Left position"
	lab var per104 "Military: positive"
	lab var per105 "Military: negative"
	lab var welfare "Welfare position: higher values mean more welfare [per503+per504]"
	lab var intpeace "International peace position: higher values mean more peace [per102+per105+per106]"
	lab var niche "Niche party: communist, green or nationalist"
	lab var left "Left party: ecology, communist or social democrat"
	lab var right "Right party: conservative, christian democrat, nationalist"
	lab var family "Party family (Budge et al.)"
	lab var center "Center party: liberal parties and family >= 80"
	lab var milspend "Military spending: positive - negative [per104-per105]"
	lab var international "Internationalism: positive - negative [per107-per109]"
	lab var hawk "Hawk score: higher value are hawk; per104-105-106"
	lab var epp "Economic policy position: high values mean free market (Hellwig, Tavits)"
	lab var absseat "Absolute number of seats in parliament controlled by that party"
	
	keep ccode party last_ts niche-center rile welfare intpeace per104 per105 milspend international hawk epp absseat
	
	sort ccode party last_ts
	tempfile cmp
	save `cmp', replace
restore

preserve
	clear
	insheet using "WKB_update_v5.csv", comma
	
	keep ccode govtseq tog rft gparties gpshare prime 
	
	sort ccode govtseq
	tempfile wkb
	save `wkb', replace
restore

****************************************************************
*** Merge all the files
****************************************************************
use Australia--1986.dta, clear

foreach d in Australia--1990 Australia--1996 Australia--2007 Austria--1986 Bulgaria--1997 Canada--1996 Canada--2006 Croatia--2006 Czech--1996 Czech--2006 Denmark--2008 Finland--2006 France--1997 GB--1985 GB--1990 GB--1996 GB--2006 Germany--1985 Germany--1990 Germany--1996 Germany--2006 Hungary--1990 Hungary--1996 Hungary--2006 Ireland--1996 Ireland--2005 Italy--1990 Japan--1996 Japan--2006 Latvia--2007 Netherlands--2006 Norway--1990 Norway--1996 Norway--2006 NZ--1997 NZ--2006 Poland--1997 Poland--2008 Portugal--2006 Slovenia--1995 Slovenia--2006 Spain--2006 Sweden--1996 Sweden--2006 Switzerland--1998 Switzerland--2007 USA--1985 USA--1990 USA--1996 USA--2006 {
	append using `d', force
}

sort ccode year
merge ccode year using `e'
drop if _merge == 2
drop _merge

sort ccode party last_ts
merge ccode party last_ts using `cmp'
drop if _merge == 2
drop _merge

sort ccode govtseq
merge ccode govtseq using `wkb'
drop if _merge == 2
drop _merge

*** Create some other necessary variables
gen minority = tog
recode minority (1/3=0) (4/5=1) (6=.)
lab def minority 0 "Majority" 1 "Minority"
lab val minority minority
lab var minority "Minority government [WKB]"

gen coalition = tog
recode coalition (1 4=0) (2/3 5=1) (6=.)
lab def coalition 0 "Single-Party" 1 "Coalition"
lab val coalition coalition
lab var coalition "Coalition government [WKB]"

gen clarity = minority + coalition
recode clarity (0=1) (1/2=0) 
lab def clarity 0 "Low Clarity" 1 "High Clarity"
lab val clarity clarity
lab var clarity "Low clarity (coded 0) is either minority or coalition (high = 1)"

*** Create leftpm
recode pm (.=0)
recode govt (.=0)
lab def pm 0 "Non-PM" 1 "PM"
lab def govt 0 "Opposition" 1 "Government"
lab val pm pm
lab val govt govt

gen leftpm = 1 if (pm == 1) & (left == 1)
replace leftpm = 0 if (pm != 1 | left != 1)

gen rightpm = 1 if (pm == 1) & (right == 1)
replace rightpm = 0 if (pm != 1 | right != 1)

gen part = .
replace part = -1 if left == 1
replace part = 0 if center == 1
replace part = 1 if right == 1
lab def part -1 "Left" 0 "Center" 1 "Right"
lab val part part

gen dm = 0
replace dm = 1 if (pm == 1 & ccode == 2) | (party == 62420 & year == 1996) | (party == 62623 & year == 2006) | (ccode == 200 & pm == 1) | (party == 53520 & year == 1996) | (party == 53620 & year == 2005) | (party == 22420) | (party == 31320) | (party == 43810 & year == 2007) | (party == 33320) | (party == 35311) | (party == 41521) | (party == 92434 & year == 1997) | (party == 92435 & year == 2008) | (party == 42320) | (party == 86521 & year == 1990) | (party == 86220 & inlist(year, 1996, 2006)) | (party == 82413 & year == 1996) | (party == 82523 & year == 2006) | (party == 32520) | (party == 81711) | (party == 97421 & year == 1995) | (party == 97951 & year == 2006) | (party == 80220) | (party == 87610) | (party == 14810) | (party == 11320) | (party == 12620 & year == 1990) | (party == 12320 & inlist(year, 1996, 2005)) | (party == 13420) | (party == 71620) | (party == 63320 & inlist(year, 1986, 1990)) | (party == 63620 & inlist(year, 1996, 2007)) | (party == 64620 & year == 1997) | (party == 64320 & year == 2006)
lab def dm 0 "Not Defense Minister" 1 "Defense Minister"
lab val dm dm
lab var dm "Defense minister [WKB & Seki/Williams]"

gen fm = 0
replace fm = 1 if (pm == 1 & ccode == 2) | (party == 62420 & year == 1996) | (party == 62623 & year == 2006) | (ccode == 200 & pm == 1) | (party == 53320 & year == 1996) | (party == 53620 & year == 2005) | (party == 22521) | (party == 31320) | (party == 43520 & year == 1998) | (party == 43320 & year == 2007) | (party == 33320) | (party == 35311) | (party == 41420 & inlist(year, 1985, 1990, 1996)) | (party == 41320 & year == 2006) |  (party == 92434 & year == 1997) | (party == 92435 & year == 2008) | (party == 42320) | (party == 86521 & year == 1990) | (party == 86220 & inlist(year, 1996, 2006)) | (party == 32320) | (party == 81711) | (party == 97520 & year == 1995) | (party == 97330 & year == 2006) | (party == 80220) | (party == 87610) | (party == 14320) | (party == 11320) | (party == 12520 & year == 1990) | (party == 12320 & inlist(year, 1996, 2005)) | (party == 13620) | (party == 71620) | (party == 63320 & inlist(year, 1986, 1990)) | (party == 63620 & inlist(year, 1996, 2007)) | (party == 64620 & year == 1997) | (party == 64320 & year == 2006)   
lab def fm 0 "Not Foreign Affairs Minister" 1 "Foreign Affairs Minister"
lab val fm fm
lab var fm "Foreign Affairs Minister [WKB & Seki/Williams]"

*** Generate the dummy for largest opposition party
tempvar opp_seats opp
gen `opp' = cond(govt==0, 1, 0)
bys ccode year: egen `opp_seats' = max(`opp' * absseat)

gen lopp = .
replace lopp = 0 if `opp'==1 & absseat != `opp_seats'
replace lopp = 1 if `opp'==1 & absseat == `opp_seats'

*** Prime Minister, Coalition partner, Defense Minister
gen status = 0
replace status = 1 if govt == 1 & pm == 0 & dm == 0
replace status = 2 if pm == 1 & dm == 0
replace status = 3 if pm == 0 & dm == 1
replace status = 4 if pm == 1 & dm == 1
lab def status 0 "Opposition" 1 "Coalition Partner, not DM" 2 "PM, no DM" 3"DM, no PM" 4 "PM & DM"
lab val status status

*** Left and Right * PM Status
gen lr_pm = .
replace lr_pm = 1 if left == 1 & pm == 0
replace lr_pm = 2 if left == 1 & pm == 1
replace lr_pm = 3 if right == 1 & pm == 0
replace lr_pm = 4 if right == 1 & pm == 1
lab def lr_pm 1 "Left Non-PM" 2 "Left PM" 3 "Right Non-PM" 4 "Right PM"
lab val lr_pm lr_pm

*** Left and Right * PM/largest opposition party
gen lr_pm2 = .
replace lr_pm2 = 1 if left == 1 & lopp == 1
replace lr_pm2 = 2 if left == 1 & pm == 1
replace lr_pm2 = 3 if right == 1 & lopp == 1
replace lr_pm2 = 4 if right == 1 & pm == 1
lab def lr_pm2 1 "Left Largest Opp." 2 "Left PM" 3 "Right Largest Opp." 4 "Right PM"
lab val lr_pm2 lr_pm2

*** Positive versus negative military spending * PM
gen milspend_pm = 1 if milspend < 0 & pm == 0
replace milspend_pm = 2 if milspend < 0 & pm == 1
replace milspend_pm = 3 if milspend > 0 & pm == 0
replace milspend_pm = 4 if milspend > 0 & pm == 1
lab def milspend_pm 1 "Negative Non-PM" 2 "Negative PM" 3 "Positive Non-PM" 4 "Positive PM"
lab val milspend_pm milspend_pm

*** Positive versus negative military spending * PM/largest opposition party
gen milspend_pm2 = 1 if milspend < 0 & lopp == 1
replace milspend_pm2 = 2 if milspend < 0 & pm == 1
replace milspend_pm2 = 3 if milspend > 0 & lopp == 1
replace milspend_pm2 = 4 if milspend > 0 & pm == 1
lab def milspend_pm2 1 "Negative Largest Opp." 2 "Negative PM" 3 "Positive Largest Opp." 4 "Positive PM"
lab val milspend_pm2 milspend_pm2

sort pr
gen id = _n
gen lo = pr - (1.65 * se)
gen hi = pr + (1.65 * se)
gen sig = cond((pr < 0 & hi < 0) | (pr > 0 & lo > 0), 1, 0)

lab var pm "PM party"
lab var govt "Government party (including PM)"
lab var leftpm "Left PM"
lab var rightpm "Right PM"
lab var part "Partisanship: left (-1), center (0), or right (1)"
lab var pr "Party-specific average change in probability of voting"
lab var se "Party-specific standard error for average change in probability of voting"
lab var N "Number of observations in each survey-specific estimation"
lab var obs "Survey-specific party identifier"
lab var ccode "Correlates of War country code"
lab var year "Year of fieldwork"
lab var party "Comparative Manifesto Project party code"
lab var id "Party-specific identifer, based on the size of pr"
lab var lo "Lower 90% confidence interval"
lab var hi "Upper 90% confidence interval"
lab var sig "Dummy variable for statistical significance at 90% confidence level"
lab var status "Status in government/opposition"
lab var lr_pm "Left and Right * PM Status"
lab var lr_pm2 "Left and Right * PM/largest opposition party"
lab var milspend_pm "Positive versus negative military spending * PM"
lab var milspend_pm2 "Positive versus negative military spending * PM/largest opposition party"
lab var lopp "Dummy for largest opposition party (govt == .)"

*** Generate the election-specific defense spending vote
bys ccode year: egen dsv = total(abs(pr))
lab var dsv "Defense spending vote: aggregated absolute values of probability changes in that election"

lab val ccode ccode

*** Descriptives
preserve
	cap log close
	log using "Defense Spending--Descriptive Statistics.smcl", replace
	
	collapse (count) parties = party (mean) N mid_count_h_36, by(ccode year)
	
	sort ccode year
	list ccode year parties N mid_count_h_36, sepby(ccode)
	
	log close
restore

sort ccode last_ts party


*** Defense Spending
preserve
	keep ccode - govtseq rile milspend lopp - dsv mid_count_h_36
	save "DSV.dta", replace 
restore

save "ISSP--Defense Spending--Vote Choice.dta", replace
