**************************************************************
*** Replication file for Somer-Topcu and Williams' "Opposition Party Policy Shifts in Response to No-Confidence Motions", EJPR
***
*** Created: 5-3-13
**************************************************************

* Set up working directory!
*cd "C:"

* Open the data!
use "Somer-Topcu and Williams EJPR Replication.dta", clear

cap log close
log using "EJPR--Replication.smcl", replace

*************************************************************************
*************************************************************************
************************** Replication **********************************
*************************************************************************
*************************************************************************
* Main Model
reg dv_towardaway ncm_election_12 rgdppc_growth ncm_gdp_12 niche effect_numt1 dv_towardaway_lagged if lastgov == 0 & ncm_pass_election!=1, cluster(index)

* Scandals
reg dv_towardaway ncm_election_12 scandal2 ncmxscandal2 niche effect_numt1 dv_towardaway_lagged if lastgov == 0 & ncm_pass_election!=1, cluster(index)

* Proposers and non-proposers
reg dv_towardaway ncm_election_12 ncm_election_p_12 rgdppc_growth ncm_gdp_12 p_ncm_gdp_12 niche effect_numt1 dv_towardaway_lagged if lastgov == 0 & ncm_pass_election!=1, cluster(index)

* Economic NCMs
reg dv_towardaway ncm_econ_election_12 rgdppc_growth ncm_econ_gdp_12 niche effect_numt1 dv_towardaway_lagged if lastgov == 0 & ncm_pass_election!=1, cluster(index)

* Other NCMs
reg dv_towardaway ncm_other_election_12 rgdppc_growth ncm_other_gdp_12 niche effect_numt1 dv_towardaway_lagged if lastgov == 0 & ncm_pass_election!=1, cluster(index)


*************************************************************************
*** Figure 1: Marginal effect of a no-confidence motion across economic growth (main model)
*** NOTE: Exact replication code is found in the "Somer-Topcu and Williams EJPR--Figure Replication.R" file.
*************************************************************************
qui reg dv_towardaway ncm_election_12 rgdppc_growth ncm_gdp_12 niche effect_numt1 dv_towardaway_lagged if lastgov == 0 & ncm_pass_election!=1, cluster(index)

matrix b=e(b)
matrix V=e(V)
local k = colsof(b)
foreach c of numlist 1(1)`k' {
	local b`c' = b[1,`c']
	local varb`c' = V[`c',`c']
	foreach r of numlist 1(1)`k' {
		local covb`r'b`c' = V[`r',`c']
	}
}

postfile int Z ME_X SE_X LO_X HI_X using "Marginal Effects.dta", replace

* Calculate the ME of an NCM across GDP Growth
foreach i of numlist -4.5(.5)4.5 {
	local ME_X = `b1' + (`b3' * `i')
	local i_s = `i'*`i'
	local i_t2 = `i'*2
	local SE_X = sqrt((`varb1')+(`i_s'*`varb3')+(`i_t2'*`covb1b3'))
	local LO_X = `ME_X' - (1.96 * `SE_X')
	local HI_X = `ME_X' + (1.96 * `SE_X')
	
	post int (`i') (`ME_X') (`SE_X') (`LO_X') (`HI_X')

}

postclose int

preserve
	use "Marginal Effects.dta", clear

	twoway (line ME_X Z) (line LO_X Z, lpattern(dash)) (line HI_X Z, lpattern(dash)), /*
	*/	xtitle("GDP Growth") ytitle("Marginal Effect of an NCM") xlabel(-4.5(1)4.5) yline(0) legend(off) scheme(s1mono)
restore


*************************************************************************
*************************************************************************
************************* Robustness Checks *****************************
*************************************************************************
*************************************************************************

*************************************************************************
*** The Effects of NCMs on Non-Economic Issues
*************************************************************************
reg dv_towardaway_mil ncm_mil_election_12_all niche effect_numt1 dv_towardaway_mil_lagged if lastgov == 0 & ncm_pass_election!=1, cluster(index)
di "Adjusted R^2 = " e(r2_a)

reg dv_towardaway_mil ncm_mil_election_12_all mid_count_all_12 rgdppc_growth niche effect_numt1 dv_towardaway_mil_lagged if lastgov == 0 & ncm_pass_election!=1, cluster(index)
di "Adjusted R^2 = " e(r2_a)

tempvar ch_dv_towardaway_mil
gen `ch_dv_towardaway_mil' = dv_towardaway_mil - dv_towardaway_mil_lagged
sum `ch_dv_towardaway_mil' if e(sample), det

* Figure S1: Histogram of Military-Related Ideological Change Following Military-Related No-Confidence Motions
hist dv_towardaway_mil if ncm_mil_election_12_all > 0, percent bin(5) xtitle("Away													Toward""Military-Related Ideological Change") scheme(s1mono)


*************************************************************************
*** Proposers and Non-Proposers
*************************************************************************
* Proposers and non-proposers (from the manuscript)
reg dv_towardaway ncm_election_12 ncm_election_p_12 rgdppc_growth ncm_gdp_12 p_ncm_gdp_12 niche effect_numt1 dv_towardaway_lagged if lastgov == 0 & ncm_pass_election!=1, cluster(index)

* Test the equality of coefficients with a seemingly unrelated regression (SUR)
qui reg dv_towardaway ncm_election_12 rgdppc_growth ncm_gdp_12 niche effect_numt1 dv_towardaway_lagged if inrange(year,1970,2010) & lastgov == 0 & ncm_pass_election!=1 & proposer_p_12==0
estimates store np

qui reg dv_towardaway ncm_election_p_12 rgdppc_growth p_ncm_gdp_12 niche effect_numt1 dv_towardaway_lagged if inrange(year,1970,2010) & lastgov == 0 & ncm_pass_election!=1
estimates store p

suest np p, cluster(index)
test [np_mean]ncm_gdp_12 = [p_mean]p_ncm_gdp_12

cap drop _est*

* Figure S2: Marginal effects of a No-Confidence Motion across GDP Growth for Proposers and Non-Proposers.
qui reg dv_towardaway ncm_election_12 ncm_election_p_12 rgdppc_growth ncm_gdp_12 p_ncm_gdp_12 niche effect_numt1 dv_towardaway_lagged if lastgov == 0 & ncm_pass_election!=1, cluster(index)
matrix b=e(b)
matrix V=e(V)
local k = colsof(b)
foreach c of numlist 1(1)`k' {
	local b`c' = b[1,`c']
	local varb`c' = V[`c',`c']
	foreach r of numlist 1(1)`k' {
		local covb`r'b`c' = V[`r',`c']
	}
}

postfile int Z ME_NP SE_NP LO_NP HI_NP ME_P SE_P LO_P HI_P using "Marginal Effects--Proposers.dta", replace

* Calculate the ME of an NCM across GDP Growth
qui foreach i of numlist -4.5(.25)4.5 {
	local i_s = `i'*`i'
	local i_t2 = `i'*2

	local ME_NP = `b1' + (`b4' * `i')
	local SE_NP = sqrt((`varb1')+(`i_s'*`varb4')+(`i_t2'*`covb1b4'))
	local LO_NP = `ME_NP' - (1.96 * `SE_NP')
	local HI_NP = `ME_NP' + (1.96 * `SE_NP')

	lincom ncm_election_12 + ncm_election_p_12 + (`i' * ncm_gdp_12) + (`i' * p_ncm_gdp_12)
	local ME_P = r(estimate)
	local SE_P = r(se)
	local LO_P = `ME_P' - (1.96 * `SE_P')
	local HI_P = `ME_P' + (1.96 * `SE_P')
	
	post int (`i') (`ME_NP') (`SE_NP') (`LO_NP') (`HI_NP') (`ME_P') (`SE_P') (`LO_P') (`HI_P')

}

postclose int

preserve
	use "Marginal Effects--Proposers.dta", clear

	* Non-proposers
	twoway (line ME_NP Z) (line LO_NP Z, lpattern(dash)) (line HI_NP Z, lpattern(dash)), /*
	*/	xtitle("GDP Growth") ytitle("Marginal Effect of an NCM") xlabel(-4.5(1)4.5) yline(0) legend(off) scheme(s1mono)

	* Proposers
	twoway (line ME_P Z) (line LO_P Z, lpattern(dash)) (line HI_P Z, lpattern(dash)), /*
	*/	xtitle("GDP Growth") ytitle("Marginal Effect of an NCM") xlabel(-4.5(1)4.5) yline(0) legend(off) scheme(s1mono)
restore

*************************************************************************
*** Economic and Non-Economic NCMs
*************************************************************************
* Economic NCMs (from the manuscript)
reg dv_towardaway ncm_econ_election_12 rgdppc_growth ncm_econ_gdp_12 niche effect_numt1 dv_towardaway_lagged if lastgov == 0 & ncm_pass_election!=1, cluster(index)

* Other NCMs (from the manuscript)
reg dv_towardaway ncm_other_election_12 rgdppc_growth ncm_other_gdp_12 niche effect_numt1 dv_towardaway_lagged if lastgov == 0 & ncm_pass_election!=1, cluster(index)

* Figure S3: Marginal effects of a No-Confidence Motion across GDP Growth: Economic versus Other No-Confidence Motions
* Panel a: Economic NCM
qui reg dv_towardaway ncm_econ_election_12 rgdppc_growth ncm_econ_gdp_12 niche effect_numt1 dv_towardaway_lagged if lastgov == 0 & ncm_pass_election!=1, cluster(index)

matrix b=e(b)
matrix V=e(V)
local k = colsof(b)
foreach c of numlist 1(1)`k' {
	local b`c' = b[1,`c']
	local varb`c' = V[`c',`c']
	foreach r of numlist 1(1)`k' {
		local covb`r'b`c' = V[`r',`c']
	}
}

postfile int Z ME_X SE_X LO_X HI_X using "Marginal Effects--Economic.dta", replace

foreach i of numlist -4.5(.5)4.5 {
	local ME_X = `b1' + (`b3' * `i')
	local i_s = `i'*`i'
	local i_t2 = `i'*2
	local SE_X = sqrt((`varb1')+(`i_s'*`varb3')+(`i_t2'*`covb1b3'))
	local LO_X = `ME_X' - (1.65 * `SE_X')
	local HI_X = `ME_X' + (1.65 * `SE_X')
	
	post int (`i') (`ME_X') (`SE_X') (`LO_X') (`HI_X')

}

postclose int

preserve
	use "Marginal Effects--Economic.dta", clear

	twoway (line ME_X Z) (line LO_X Z, lpattern(dash)) (line HI_X Z, lpattern(dash)), /*
	*/	xtitle("GDP Growth") ytitle("Marginal Effect of an Economic NCM") xlabel(-4.5(1)4.5) yline(0) legend(off) scheme(s1mono)
restore

* Panel b: non-economic NCM
qui reg dv_towardaway ncm_other_election_12 rgdppc_growth ncm_other_gdp_12 niche effect_numt1 dv_towardaway_lagged if lastgov == 0 & ncm_pass_election!=1, cluster(index)

matrix b=e(b)
matrix V=e(V)
local k = colsof(b)
foreach c of numlist 1(1)`k' {
	local b`c' = b[1,`c']
	local varb`c' = V[`c',`c']
	foreach r of numlist 1(1)`k' {
		local covb`r'b`c' = V[`r',`c']
	}
}

postfile int Z ME_X SE_X LO_X HI_X using "Marginal Effects--Other.dta", replace

foreach i of numlist -4.5(.5)4.5 {
	local ME_X = `b1' + (`b3' * `i')
	local i_s = `i'*`i'
	local i_t2 = `i'*2
	local SE_X = sqrt((`varb1')+(`i_s'*`varb3')+(`i_t2'*`covb1b3'))
	local LO_X = `ME_X' - (1.65 * `SE_X')
	local HI_X = `ME_X' + (1.65 * `SE_X')
	
	post int (`i') (`ME_X') (`SE_X') (`LO_X') (`HI_X')

}

postclose int

preserve
	use "Marginal Effects--Other.dta", clear

	twoway (line ME_X Z) (line LO_X Z, lpattern(dash)) (line HI_X Z, lpattern(dash)), /*
	*/	xtitle("GDP Growth") ytitle("Marginal Effect of a Non-Economic NCM") xlabel(-4.5(1)4.5) yline(0) legend(off) scheme(s1mono)
restore


*************************************************************************
*** Policy Shifts of Governing Parties
*************************************************************************
reg dv_towardaway ncm_election_12 rgdppc_growth ncm_gdp_12 niche effect_numt1 dv_towardaway_lagged if lastgov == 1 & ncm_pass_election!=1, cluster(index)
di "Adjusted R^2 = " e(r2_a)

* Figure S3: Marginal Effect of a No-Confidence Motion across GDP Growth for Government Parties (Government Model)
matrix b=e(b)
matrix V=e(V)
local k = colsof(b)
foreach c of numlist 1(1)`k' {
	local b`c' = b[1,`c']
	local varb`c' = V[`c',`c']
	foreach r of numlist 1(1)`k' {
		local covb`r'b`c' = V[`r',`c']
	}
}

postfile int Z ME_X SE_X LO_X HI_X using "Marginal Effects--Government.dta", replace

foreach i of numlist -4.5(.5)4.5 {
	local ME_X = `b1' + (`b3' * `i')
	local i_s = `i'*`i'
	local i_t2 = `i'*2
	local SE_X = sqrt((`varb1')+(`i_s'*`varb3')+(`i_t2'*`covb1b3'))
	local LO_X = `ME_X' - (1.96 * `SE_X')
	local HI_X = `ME_X' + (1.96 * `SE_X')
	
	post int (`i') (`ME_X') (`SE_X') (`LO_X') (`HI_X')
}

postclose int

preserve
	use "Marginal Effects--Government.dta", clear

	twoway (line ME_X Z) (line LO_X Z, lpattern(dash)) (line HI_X Z, lpattern(dash)), /*
	*/	xtitle("GDP Growth") ytitle("Marginal Effect of an NCM") xlabel(-4.5(1)4.5) yline(0) legend(off) scheme(s1mono)
restore


*************************************************************************
*** Alternative Explanations
*************************************************************************
reg dv_towardaway ncm_election_12 rgdppc_growth ncm_gdp_12 niche effect_numt1 dv_towardaway_lagged votech2 median_toward_away  if inrange(year,1970,2010) & lastgov == 0 & ncm_pass_election!=1, cluster(index)
di "Adjusted R^2 = " e(r2_a)


*************************************************************************
*** Restrictions on the Initiation of NCMs
*************************************************************************
reg dv_towardaway ncm_election_12 rgdppc_growth tuff tuff_ncm tuff_gdp ncm_gdp_12 tuff_ncm_gdp niche effect_numt1 dv_towardaway_lagged if lastgov == 0 & ncm_pass_election!=1, cluster(index)
di "Adjusted R^2 = " e(r2_a)
test ncm_gdp_12 = tuff_ncm_gdp

* Equality of marginal effects across systems with and without restrictions (i.e. tuff == 1 vs tuff == 0)
foreach i of numlist -5(2.5)5 {
	test (ncm_election_12 + ncm_gdp_12*`i' + tuff_ncm*0 + tuff_ncm_gdp*`i'*0) = (ncm_election_12 + ncm_gdp_12*`i' + tuff_ncm*1 + tuff_ncm_gdp*`i'*1)
}


*************************************************************************
*** Electoral Consequences of Ideological Change
*************************************************************************
reg votech1 vote_t1 votech2 ncm_election_12 dv_towardaway dv_towardaway_ncm_12 niche if lastgov==0 & inrange(year, 1970, 2010) & ncm_pass_election!=1 & rgdppc_growth<0, cluster(index)
qui sum dv_towardaway if e(sample) 
local sd = r(sd)

foreach i of numlist 0(1)4 {
	di "The number of NCMs = " `i'
	lincom `sd' * (dv_towardaway + (dv_towardaway_ncm_12*`i'))
}


*************************************************************************
*** Does economic decline lead to the occurrence of NCMs?
*************************************************************************
logit ncm_election_12_dummy rgdppc_growth votech2 niche if lastgov== 0


*************************************************************************
*** Other models mentioned in the manuscript
*************************************************************************
* Including successful NCMs
reg dv_towardaway ncm_election_12 rgdppc_growth ncm_gdp_12 niche effect_numt1 dv_towardaway_lagged if lastgov == 0, cluster(index)

* Direct effect of NCMs
reg dv_towardaway ncm_election_12 rgdppc_growth niche effect_numt1 dv_towardaway_lagged if lastgov == 0 & ncm_pass_election!=1, cluster(index)


*************************************************************************
*************************************************************************
***************** Descriptive Statistics ********************************
*************************************************************************
*************************************************************************
qui reg dv_towardaway ncm_election_12 rgdppc_growth ncm_gdp_12 niche effect_numt1 dv_towardaway_lagged if lastgov == 0 & ncm_pass_election!=1, cluster(index)

sum dv_towardaway ncm_election_12 rgdppc_growth effect_numt1 niche if e(sample)

preserve
	keep if e(sample)
	di _N
	collapse (count) number = party (min) min_ts = ts (max) max_ts = ts, by(countrycode)
	list countrycode number min_ts max_ts
restore

cap log close

